@@ -45,7 +45,7 @@ const char* PageTagToName(PageTag tag) {
 
 zx_vm_option_t PageAccessibilityToZxVmOptions(
     PageAccessibilityConfiguration accessibility) {
-  switch (accessibility) {
+  switch (accessibility.permissions) {
     case PageAccessibilityConfiguration::kRead:
       return ZX_VM_PERM_READ;
     case PageAccessibilityConfiguration::kReadWrite:
@@ -72,10 +72,12 @@ constexpr bool kHintIsAdvisory = false;
 
 std::atomic<int32_t> s_allocPageErrorCode{0};
 
-uintptr_t SystemAllocPagesInternal(uintptr_t hint,
-                                   size_t length,
-                                   PageAccessibilityConfiguration accessibility,
-                                   PageTag page_tag) {
+uintptr_t SystemAllocPagesInternal(
+    uintptr_t hint,
+    size_t length,
+    PageAccessibilityConfiguration accessibility,
+    PageTag page_tag,
+    [[maybe_unused]] int file_descriptor_for_shared_alloc) {
   zx::vmo vmo;
   zx_status_t status = zx::vmo::create(length, 0, &vmo);
   if (status != ZX_OK) {
@@ -109,9 +111,8 @@ uintptr_t SystemAllocPagesInternal(uintptr_t hint,
   }
 
   uint64_t address;
-  status =
-      zx::vmar::root_self()->map(options, vmar_offset, vmo,
-                                 /*vmo_offset=*/0, length, &address);
+  status = zx::vmar::root_self()->map(options, vmar_offset, vmo,
+                                      /*vmo_offset=*/0, length, &address);
   if (status != ZX_OK) {
     // map() is expected to fail if |hint| is set to an already-in-use location.
     if (!hint) {
@@ -171,8 +172,6 @@ void FreePagesInternal(uint64_t address, size_t length) {
 }
 
 void DiscardSystemPagesInternal(uint64_t address, size_t length) {
-  // TODO(https://crbug.com/1022062): Mark pages as discardable, rather than
-  // forcibly de-committing them immediately, when Fuchsia supports it.
   zx_status_t status = zx::vmar::root_self()->op_range(
       ZX_VMO_OP_DECOMMIT, address, length, nullptr, 0);
   PA_ZX_CHECK(status == ZX_OK, status);
@@ -185,22 +184,18 @@ void DecommitSystemPagesInternal(
   if (accessibility_disposition ==
       PageAccessibilityDisposition::kRequireUpdate) {
     SetSystemPagesAccess(address, length,
-                         PageAccessibilityConfiguration::kInaccessible);
+                         PageAccessibilityConfiguration(
+                             PageAccessibilityConfiguration::kInaccessible));
   }
 
-  // TODO(https://crbug.com/1022062): Review whether this implementation is
-  // still appropriate once DiscardSystemPagesInternal() migrates to a "lazy"
-  // discardable API.
   DiscardSystemPagesInternal(address, length);
 }
 
 void DecommitAndZeroSystemPagesInternal(uintptr_t address, size_t length) {
   SetSystemPagesAccess(address, length,
-                       PageAccessibilityConfiguration::kInaccessible);
+                       PageAccessibilityConfiguration(
+                           PageAccessibilityConfiguration::kInaccessible));
 
-  // TODO(https://crbug.com/1022062): this implementation will likely no longer
-  // be appropriate once DiscardSystemPagesInternal() migrates to a "lazy"
-  // discardable API.
   DiscardSystemPagesInternal(address, length);
 }
 
