@@ -14,7 +14,6 @@
 #include "base/allocator/partition_allocator/partition_address_space.h"
 #include "base/allocator/partition_allocator/partition_alloc_base/debug/debugging_buildflags.h"
 #include "base/allocator/partition_allocator/partition_alloc_buildflags.h"
-#include "base/allocator/partition_allocator/partition_alloc_config.h"
 #include "base/allocator/partition_allocator/partition_alloc_hooks.h"
 #include "base/allocator/partition_allocator/partition_direct_map_extent.h"
 #include "base/allocator/partition_allocator/partition_oom.h"
@@ -105,16 +104,6 @@ void PartitionAllocGlobalUninitForTesting() {
 #if BUILDFLAG(ENABLE_PKEYS)
   internal::PartitionAddressSpace::UninitPkeyPoolForTesting();
 #endif
-#if BUILDFLAG(USE_STARSCAN)
-  internal::PCScan::UninitForTesting();  // IN-TEST
-#endif
-#if !BUILDFLAG(USE_PARTITION_ALLOC_AS_MALLOC)
-#if PA_CONFIG(HAS_64_BITS_POINTERS)
-  internal::PartitionAddressSpace::UninitForTesting();
-#else
-  internal::AddressPoolManager::GetInstance().ResetForTesting();
-#endif  // PA_CONFIG(HAS_64_BITS_POINTERS)
-#endif  // !BUILDFLAG(USE_PARTITION_ALLOC_AS_MALLOC)
   internal::g_oom_handling_function = nullptr;
 }
 
