@@ -1,12 +1,16 @@
-// Copyright 2018 The Chromium Authors. All rights reserved.
+// Copyright 2018 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
 #ifndef BASE_ANDROID_TASK_SCHEDULER_TASK_RUNNER_ANDROID_H_
 #define BASE_ANDROID_TASK_SCHEDULER_TASK_RUNNER_ANDROID_H_
 
+#include <memory>
+
 #include "base/android/jni_weak_ref.h"
+#include "base/base_export.h"
 #include "base/task/single_thread_task_runner.h"
+#include "base/task/task_traits_extension.h"
 
 namespace base {
 
@@ -15,7 +19,7 @@ enum class TaskRunnerType { BASE, SEQUENCED, SINGLE_THREAD };
 
 // Native implementation backing TaskRunnerImpl.java which posts java tasks onto
 // a C++ TaskRunner.
-class TaskRunnerAndroid {
+class BASE_EXPORT TaskRunnerAndroid {
  public:
   explicit TaskRunnerAndroid(scoped_refptr<TaskRunner> task_runner,
                              TaskRunnerType type);
@@ -34,6 +38,11 @@ class TaskRunnerAndroid {
 
   bool BelongsToCurrentThread(JNIEnv* env);
 
+  static std::unique_ptr<TaskRunnerAndroid> Create(jint task_runner_type,
+                                                   jint j_task_traits);
+
+  static void SetUiThreadExtension(TaskTraitsExtensionStorage extension);
+
  private:
   const scoped_refptr<TaskRunner> task_runner_;
   const TaskRunnerType type_;
