@@ -15,6 +15,7 @@
 
 #include "base/allocator/partition_allocator/partition_alloc_buildflags.h"
 #include "base/allocator/partition_allocator/partition_alloc_config.h"
+#include "base/allocator/partition_allocator/pointers/raw_ptr.h"
 #include "base/check.h"
 #include "base/compiler_specific.h"
 #include "base/functional/callback_internal.h"
@@ -108,65 +109,67 @@ namespace internal {
 template <typename Functor, typename SFINAE = void>
 struct FunctorTraits;
 
-template <typename T, typename Trait>
+template <typename T,
+          typename UnretainedTrait,
+          RawPtrTraits PtrTraits = RawPtrTraits::kEmpty>
 class UnretainedWrapper {
-  // We want the getter type to be the exact same as the receiver parameter that
-  // it's passed into, to avoid having raw_ptr<T> -> T* -> raw_ptr<T> round
-  // trip, which could trigger the raw_ptr error detector if T* was dangling.
-  // This is enforced by static_asserts in base::internal::AssertConstructible.
-  //
-  // Returning raw_ptr<T> would also break if e.g. UnretainedWrapper() is
-  // constructed using char*, but the receiver is of type std::string&.
-  using GetPtrType =
-      std::conditional_t<std::is_same_v<Trait, unretained_traits::MayDangle>,
-                         MayBeDangling<T>,
-                         T*>;
+  // Note that if PtrTraits already includes MayDangle, DanglingRawPtrType
+  // will be identical to `raw_ptr<T, PtrTraits>`.
+  using DanglingRawPtrType = MayBeDangling<T, PtrTraits>;
 
  public:
+  // We want the getter type to match the receiver parameter that it is passed
+  // into, to minimize `raw_ptr<T>` <-> `T*` conversions. We also would like to
+  // match `StorageType`, but sometimes we can't have both, as shown in
+  // https://docs.google.com/document/d/1dLM34aKqbNBfRdOYxxV_T-zQU4J5wjmXwIBJZr7JvZM/edit
+  // When we can't have both, prefer the former, mostly because
+  // `GetPtrType`=`raw_ptr<T>` would break if e.g. UnretainedWrapper() is
+  // constructed using `char*`, but the receiver is of type `std::string&`.
+  // This is enforced by static_asserts in base::internal::AssertConstructible.
+  using GetPtrType = std::conditional_t<
+      raw_ptr_traits::IsSupportedType<T>::value &&
+          std::is_same_v<UnretainedTrait, unretained_traits::MayDangle>,
+      DanglingRawPtrType,
+      T*>;
+
   static_assert(TypeSupportsUnretainedV<T>,
                 "Callback cannot capture an unprotected C++ pointer since this "
                 "Type is annotated with DISALLOW_UNRETAINED(). Please see "
                 "base/functional/disallow_unretained.h for alternatives.");
 
+  // Raw pointer makes sense only if there are no PtrTraits. If there are,
+  // it means that a `raw_ptr` is being passed, so use the ctors below instead.
+  template <RawPtrTraits PTraits = PtrTraits,
+            typename = std::enable_if_t<PTraits == RawPtrTraits::kEmpty>>
   explicit UnretainedWrapper(T* o) : ptr_(o) {}
 
   // Trick to only instantiate these constructors if they are used. Otherwise,
   // instantiating UnretainedWrapper with a T that is not supported by
   // raw_ptr would trigger raw_ptr<T>'s static_assert.
-  template <typename U = T, typename Traits>
-  explicit UnretainedWrapper(const raw_ptr<U, Traits>& o) : ptr_(o) {}
-  template <typename U = T, typename Traits>
-  explicit UnretainedWrapper(raw_ptr<U, Traits>&& o) : ptr_(std::move(o)) {}
+  template <typename U = T>
+  explicit UnretainedWrapper(const raw_ptr<U, PtrTraits>& o) : ptr_(o) {}
+  template <typename U = T>
+  explicit UnretainedWrapper(raw_ptr<U, PtrTraits>&& o) : ptr_(std::move(o)) {}
 
-  template <typename U, typename Traits>
-  static void ReportIfDangling(const raw_ptr<U, Traits>& ptr) {
-    if constexpr (std::is_same_v<Trait, unretained_traits::MayNotDangle>) {
-      ptr.ReportIfDangling();
-    }
-  }
-  template <typename U>
-  static void ReportIfDangling(U* ptr) {}
-
-  GetPtrType get() const {
-    // `ptr_` is either a `raw_ptr` (if `T` is a supported type) or a regular
-    // C++ pointer otherwise.
-    ReportIfDangling(ptr_);
-    return ptr_;
-  }
+  GetPtrType get() const { return GetInternal(ptr_); }
 
  private:
-#if PA_CONFIG(ENABLE_MTE_CHECKED_PTR_SUPPORT_WITH_64_BITS_POINTERS)
-  // When `MTECheckedPtr` is enabled as the backing implementation of
-  // `raw_ptr`, there are too many different types that immediately
-  // cause Chrome to crash. Some of these are inutterable as forward
-  // declarations in `raw_ptr.h` (necessary to mark it as not
-  // `IsSupportedType`) - in particular, nested classes
-  // (`Foo::UnsupportedFoo`) cannot be marked as unsupported.
-  //
-  // As a compromise, we decay the wrapper to use `T*` only (rather
-  // than `raw_ptr`) when `raw_ptr` is `MTECheckedPtr`.
-  using StorageType = T*;
-#else   // PA_CONFIG(ENABLE_MTE_CHECKED_PTR_SUPPORT_WITH_64_BITS_POINTERS)
+  // `ptr_` is either a `raw_ptr` or a regular C++ pointer.
+  template <typename U>
+  static GetPtrType GetInternal(U* ptr) {
+    static_assert(std::is_same_v<T, U>);
+    return ptr;
+  }
+  template <typename U, RawPtrTraits Traits>
+  static GetPtrType GetInternal(const raw_ptr<U, Traits>& ptr) {
+    static_assert(std::is_same_v<T, U>);
+    if constexpr (std::is_same_v<UnretainedTrait,
+                                 unretained_traits::MayNotDangle>) {
+      ptr.ReportIfDangling();
+    }
+    return ptr;
+  }
+
   // `Unretained()` arguments often dangle by design (a common design pattern
   // is to manage an object's lifetime inside the callback itself, using
   // stateful information), so disable direct dangling pointer detection
@@ -178,31 +181,27 @@ class UnretainedWrapper {
   // pointer value via `get()` above.
   using StorageType =
       std::conditional_t<raw_ptr_traits::IsSupportedType<T>::value,
-                         MayBeDangling<T>,
+                         DanglingRawPtrType,
                          T*>;
-#endif  // PA_CONFIG(ENABLE_MTE_CHECKED_PTR_SUPPORT_WITH_64_BITS_POINTERS)
   // Avoid converting between different `raw_ptr` types when calling `get()`.
-  // See the comment by `GetPtrType` describing why this wouldn't be good.
+  // It is allowable to convert `raw_ptr<T>` -> `T*`, but not in the other
+  // direction. See the comment by `GetPtrType` describing for more details.
   static_assert(std::is_pointer_v<GetPtrType> ||
-                std::is_pointer_v<StorageType> ||
                 std::is_same_v<GetPtrType, StorageType>);
   StorageType ptr_;
 };
 
 // Storage type for std::reference_wrapper so `BindState` can internally store
-// unprotected references using raw_ptr.
+// unprotected references using raw_ref.
 //
 // std::reference_wrapper<T> and T& do not work, since the reference lifetime is
 // not safely protected by MiraclePtr.
 //
 // UnretainedWrapper<T> and raw_ptr<T> do not work, since BindUnwrapTraits would
 // try to pass by T* rather than T&.
-//
-// raw_ref<T> is not used to differentiate between storing a `raw_ref<T>`
-// explicitly versus storing a `T&` or `std::ref()`.
 template <typename T,
-          typename Trait,
-          bool = raw_ptr_traits::IsSupportedType<T>::value>
+          typename UnretainedTrait,
+          RawPtrTraits PtrTraits = RawPtrTraits::kEmpty>
 class UnretainedRefWrapper {
  public:
   static_assert(
@@ -211,82 +210,83 @@ class UnretainedRefWrapper {
       "type is annotated with DISALLOW_UNRETAINED(). Please see "
       "base/functional/disallow_unretained.h for alternatives.");
 
+  // Raw reference makes sense only if there are no PtrTraits. If there are,
+  // it means that a `raw_ref` is being passed, so use the ctors below instead.
+  template <RawPtrTraits PTraits = PtrTraits,
+            typename = std::enable_if_t<PTraits == RawPtrTraits::kEmpty>>
   explicit UnretainedRefWrapper(T& o) : ref_(o) {}
 
   // Trick to only instantiate these constructors if they are used. Otherwise,
   // instantiating UnretainedWrapper with a T that is not supported by
   // raw_ref would trigger raw_ref<T>'s static_assert.
-  //
-  // This is only needed when <T, Trait, true> specialization isn't compiled in
-  // when MTECheckedPtr is enabled.
-  template <typename U = T, typename Traits>
-  explicit UnretainedRefWrapper(const raw_ref<U, Traits>& o) : ref_(o.get()) {}
-  template <typename U = T, typename Traits>
-  explicit UnretainedRefWrapper(raw_ref<U, Traits>&& o) : ref_(o.get()) {}
+  template <typename U = T>
+  explicit UnretainedRefWrapper(const raw_ref<U, PtrTraits>& o) : ref_(o) {}
+  template <typename U = T>
+  explicit UnretainedRefWrapper(raw_ref<U, PtrTraits>&& o)
+      : ref_(std::move(o)) {}
 
-  T& get() const { return ref_; }
+  T& get() const { return GetInternal(ref_); }
 
  private:
-  T& ref_;
-};
-
-#if !PA_CONFIG(ENABLE_MTE_CHECKED_PTR_SUPPORT_WITH_64_BITS_POINTERS)
-// Implementation of UnretainedRefWrapper for `T` where raw_ref<T> is supported.
-template <typename T, typename Trait>
-class UnretainedRefWrapper<T, Trait, true> {
- public:
-  static_assert(TypeSupportsUnretainedV<T>,
-                "Callback cannot capture an unprotected C++ pointer since this "
-                "type is annotated with DISALLOW_UNRETAINED(). Please see "
-                "base/functional/disallow_unretained.h for alternatives.");
-
-  explicit UnretainedRefWrapper(T& o) : ref_(o) {}
-  template <typename U = T, typename Traits>
-  explicit UnretainedRefWrapper(const raw_ref<U, Traits>& o) : ref_(o.get()) {}
-  template <typename U = T, typename Traits>
-  explicit UnretainedRefWrapper(raw_ref<U, Traits>&& o) : ref_(o.get()) {}
-  T& get() const {
+  // `ref_` is either a `raw_ref` or a regular C++ reference.
+  template <typename U>
+  static T& GetInternal(U& ref) {
+    static_assert(std::is_same_v<T, U>);
+    return ref;
+  }
+  template <typename U, RawPtrTraits Traits>
+  static T& GetInternal(const raw_ref<U, Traits>& ref) {
+    static_assert(std::is_same_v<T, U>);
     // The ultimate goal is to crash when a callback is invoked with a
     // dangling pointer. This is checked here. For now, it is configured to
     // either crash, DumpWithoutCrashing or be ignored. This depends on the
     // PartitionAllocUnretainedDanglingPtr feature.
-    if constexpr (std::is_same_v<Trait, unretained_traits::MayNotDangle>) {
-      ref_.ReportIfDangling();
+    if constexpr (std::is_same_v<UnretainedTrait,
+                                 unretained_traits::MayNotDangle>) {
+      ref.ReportIfDangling();
     }
     // We can't use operator* here, we need to use raw_ptr's GetForExtraction
     // instead of GetForDereference. If we did use GetForDereference then we'd
     // crash in ASAN builds on calling a bound callback with a dangling
-    // reference parameter even if that parameter is not used. This could hide a
-    // later unprotected issue that would be reached in release builds.
-    return ref_.get();
+    // reference parameter even if that parameter is not used. This could hide
+    // a later unprotected issue that would be reached in release builds.
+    return ref.get();
   }
 
- private:
-  // Similarly to `UnretainedWrapper`, we cannot enable the dangling pointer
-  // detector (DPD) on this raw_ref, because it is a very common pattern to have
-  // dangling ptrs/references in never-used callbacks. For this reason, we
-  // disable DPD here. Instead we check it is not dangling when the callback is
-  // invoked, by using `ReportIfDangling`.
-  const raw_ref<T, DisableDanglingPtrDetection> ref_;
+  // `Unretained()` arguments often dangle by design (a common design pattern
+  // is to manage an object's lifetime inside the callback itself, using
+  // stateful information), so disable direct dangling pointer detection
+  // of `ref_`.
+  //
+  // If the callback is invoked, dangling pointer detection will be triggered
+  // before invoking the bound functor (unless stated otherwise, see
+  // `UnsafeDangling()` and `UnsafeDanglingUntriaged()`), when retrieving the
+  // pointer value via `get()` above.
+  using StorageType =
+      std::conditional_t<raw_ptr_traits::IsSupportedType<T>::value,
+                         raw_ref<T, DisableDanglingPtrDetection>,
+                         T&>;
+
+  StorageType ref_;
 };
-#endif  // !PA_CONFIG(ENABLE_MTE_CHECKED_PTR_SUPPORT_WITH_64_BITS_POINTERS)
 
 // The class is used to wrap `UnretainedRefWrapper` when the latter is used as
 // a method receiver (a reference on `this` argument). This is needed because
 // the internal callback mechanism expects the receiver to have the type
 // `MyClass*` and to have `operator*`.
 // This is used as storage.
-template <typename T, typename Trait, bool b>
+template <typename T, typename UnretainedTrait, RawPtrTraits PtrTraits>
 class UnretainedRefWrapperReceiver {
  public:
   // NOLINTNEXTLINE(google-explicit-constructor)
-  UnretainedRefWrapperReceiver(UnretainedRefWrapper<T, Trait, b>&& o)
+  UnretainedRefWrapperReceiver(
+      UnretainedRefWrapper<T, UnretainedTrait, PtrTraits>&& o)
       : obj_(std::move(o)) {}
   // NOLINTNEXTLINE(google-explicit-constructor)
   T& operator*() const { return obj_.get(); }
 
  private:
-  UnretainedRefWrapper<T, Trait, b> obj_;
+  UnretainedRefWrapper<T, UnretainedTrait, PtrTraits> obj_;
 };
 
 // MethodReceiverStorageType converts the current receiver type to its stored
@@ -299,11 +299,12 @@ struct MethodReceiverStorageType {
       std::conditional_t<IsPointerV<T>, scoped_refptr<RemovePointerT<T>>, T>;
 };
 
-template <typename T, typename Trait, bool b>
-struct MethodReceiverStorageType<UnretainedRefWrapper<T, Trait, b>> {
+template <typename T, typename UnretainedTrait, RawPtrTraits PtrTraits>
+struct MethodReceiverStorageType<
+    UnretainedRefWrapper<T, UnretainedTrait, PtrTraits>> {
   // We can't use UnretainedRefWrapper as a receiver directly (see
   // UnretainedRefWrapperReceiver for why).
-  using Type = UnretainedRefWrapperReceiver<T, Trait, b>;
+  using Type = UnretainedRefWrapperReceiver<T, UnretainedTrait, PtrTraits>;
 };
 
 template <typename T>
@@ -888,9 +889,9 @@ struct StorageTraits<T*> {
 // For raw_ptr<T>, store as UnretainedWrapper<T> for safety. This may seem
 // contradictory, but this ensures guaranteed protection for the pointer even
 // during execution of callbacks with parameters of type raw_ptr<T>.
-template <typename T, typename I>
-struct StorageTraits<raw_ptr<T, I>> {
-  using Type = UnretainedWrapper<T, unretained_traits::MayNotDangle>;
+template <typename T, RawPtrTraits PtrTraits>
+struct StorageTraits<raw_ptr<T, PtrTraits>> {
+  using Type = UnretainedWrapper<T, unretained_traits::MayNotDangle, PtrTraits>;
 };
 
 // Unwrap std::reference_wrapper and store it in a custom wrapper so that
@@ -1344,15 +1345,32 @@ struct IsOnceCallback : std::false_type {};
 template <typename Signature>
 struct IsOnceCallback<OnceCallback<Signature>> : std::true_type {};
 
-// IsUnretainedMayDangle is true if |T| is of type
-// UnretainedWrapper<T, unretained_traits::MayDangle>.
+// IsUnretainedMayDangle is true if StorageType is of type
+// `UnretainedWrapper<T, unretained_traits::MayDangle, PtrTraits>.
 // Note that it is false for unretained_traits::MayDangleUntriaged.
-template <typename T>
+template <typename StorageType>
 inline constexpr bool IsUnretainedMayDangle = false;
-template <typename T>
-inline constexpr bool
-    IsUnretainedMayDangle<UnretainedWrapper<T, unretained_traits::MayDangle>> =
-        true;
+template <typename T, RawPtrTraits PtrTraits>
+inline constexpr bool IsUnretainedMayDangle<
+    UnretainedWrapper<T, unretained_traits::MayDangle, PtrTraits>> = true;
+
+// UnretainedAndRawPtrHaveCompatibleTraits is true if StorageType is of type
+// `UnretainedWrapper<T, unretained_traits::MayDangle, PtrTraits1>` and
+// FunctionParamType is of type `raw_ptr<T, PtrTraits2>`, and the former's
+// ::GetPtrType is the same type as the latter.
+template <typename StorageType, typename FunctionParamType>
+inline constexpr bool UnretainedAndRawPtrHaveCompatibleTraits = false;
+template <typename T,
+          RawPtrTraits PtrTraitsInUnretained,
+          RawPtrTraits PtrTraitsInReceiver>
+inline constexpr bool UnretainedAndRawPtrHaveCompatibleTraits<
+    UnretainedWrapper<T, unretained_traits::MayDangle, PtrTraitsInUnretained>,
+    raw_ptr<T, PtrTraitsInReceiver>> =
+    std::is_same_v<
+        typename UnretainedWrapper<T,
+                                   unretained_traits::MayDangle,
+                                   PtrTraitsInUnretained>::GetPtrType,
+        raw_ptr<T, PtrTraitsInReceiver>>;
 
 // Helpers to make error messages slightly more readable.
 template <int i>
@@ -1409,24 +1427,38 @@ struct BindArgument {
       // true if we are handling `this` parameter.
       static constexpr bool kParamIsThisPointer = is_method && i == 0;
       // true if the current parameter is of type `raw_ptr<T>` with
-      // raw_ptr_traits::MayDangle trait (e.g. `MayBeDangling<T>`).
+      // `RawPtrTraits::kMayDangle` trait (e.g. `MayBeDangling<T>`).
       static constexpr bool kParamIsDanglingRawPtr =
           IsRawPtrMayDangleV<FunctionParamType>;
       // true if the bound parameter is of type
-      // `UnretainedWrapper<T, unretained_traits::MayDangle>`.
+      // `UnretainedWrapper<T, unretained_traits::MayDangle, PtrTraits>`.
       static constexpr bool kBoundPtrMayDangle =
           IsUnretainedMayDangle<StorageType>;
+      // true if bound parameter of type `UnretainedWrapper` and parameter of
+      // type `raw_ptr` have compatible `RawPtrTraits`.
+      static constexpr bool kMayBeDanglingTraitsCorrectness =
+          UnretainedAndRawPtrHaveCompatibleTraits<StorageType,
+                                                  FunctionParamType>;
       // true if the receiver argument **must** be of type `MayBeDangling<T>`.
       static constexpr bool kMayBeDanglingMustBeUsed =
           kBoundPtrMayDangle && kParamIsDanglingRawPtr;
+
       // true iff:
       // - bound parameter is of type
-      //   `UnretainedWrapper<T, unretained_traits::MayDangle>`
+      //   `UnretainedWrapper<T, unretained_traits::MayDangle, PtrTraits>`
       // - the receiving argument is of type `MayBeDangling<T>`
       template <bool is_method>
       static constexpr bool kMayBeDanglingPtrPassedCorrectly =
           kParamIsThisPointer<is_method> ||
           kBoundPtrMayDangle == kParamIsDanglingRawPtr;
+
+      // true if:
+      // - MayBeDangling<T> must not be used as receiver parameter.
+      // OR
+      // - MayBeDangling<T> must be used as receiver parameter and its traits
+      // are matching Unretained traits.
+      static constexpr bool kUnsafeDanglingAndMayBeDanglingHaveMatchingTraits =
+          !kMayBeDanglingMustBeUsed || kMayBeDanglingTraitsCorrectness;
     };
   };
 };
@@ -1517,6 +1549,12 @@ struct AssertConstructible {
           Storage>::template kMayBeDanglingPtrPassedCorrectly<is_method>,
       "base::UnsafeDangling() pointers must be received by functors with "
       "MayBeDangling<T> as parameter.");
+
+  static_assert(
+      BindArgument<i>::template ToParamWithType<Param>::template StoredAs<
+          Storage>::kUnsafeDanglingAndMayBeDanglingHaveMatchingTraits,
+      "MayBeDangling<T> parameter must receive the same RawPtrTraits as the "
+      "one passed to the corresponding base::UnsafeDangling() call.");
 };
 
 // Takes three same-length TypeLists, and applies AssertConstructible for each
@@ -1696,16 +1734,20 @@ struct BindUnwrapTraits {
   }
 };
 
-template <typename T, typename Trait>
-struct BindUnwrapTraits<internal::UnretainedWrapper<T, Trait>> {
-  static auto Unwrap(const internal::UnretainedWrapper<T, Trait>& o) {
+template <typename T, typename UnretainedTrait, RawPtrTraits PtrTraits>
+struct BindUnwrapTraits<
+    internal::UnretainedWrapper<T, UnretainedTrait, PtrTraits>> {
+  static auto Unwrap(
+      const internal::UnretainedWrapper<T, UnretainedTrait, PtrTraits>& o) {
     return o.get();
   }
 };
 
-template <typename T, typename Trait>
-struct BindUnwrapTraits<internal::UnretainedRefWrapper<T, Trait>> {
-  static T& Unwrap(const internal::UnretainedRefWrapper<T, Trait>& o) {
+template <typename T, typename UnretainedTrait, RawPtrTraits PtrTraits>
+struct BindUnwrapTraits<
+    internal::UnretainedRefWrapper<T, UnretainedTrait, PtrTraits>> {
+  static T& Unwrap(
+      const internal::UnretainedRefWrapper<T, UnretainedTrait, PtrTraits>& o) {
     return o.get();
   }
 };
