@@ -10,22 +10,22 @@
 #if BUILDFLAG(USE_ASAN_BACKUP_REF_PTR)
 #include <cstddef>
 #include <cstdint>
+#include <memory>
 #include <vector>
 
 #include "base/base_export.h"
 #include "base/containers/stack_container.h"
 #include "base/memory/raw_ptr.h"
-#include "base/threading/thread_local.h"
 
 namespace base {
 namespace internal {
 template <typename, typename>
 struct Invoker;
 
-template <typename T, typename Impl>
+template <typename T, typename UnretainedTrait, RawPtrTraits PtrTraits>
 class UnretainedWrapper;
 
-template <typename T, typename RawPtrType, bool>
+template <typename T, typename UnretainedTrait, RawPtrTraits PtrTraits>
 class UnretainedRefWrapper;
 }  // namespace internal
 
@@ -46,6 +46,9 @@ class UnretainedRefWrapper;
 // the Bind implementation. This should not be used directly.
 class BASE_EXPORT RawPtrAsanBoundArgTracker {
  public:
+  static constexpr size_t kInlineArgsCount = 3;
+  using ProtectedArgsVector = base::StackVector<uintptr_t, kInlineArgsCount>;
+
   // Check whether ptr is an address inside an allocation pointed to by one of
   // the currently protected callback arguments. If it is, then this function
   // returns the base address of that allocation, otherwise it returns 0.
@@ -69,20 +72,28 @@ class BASE_EXPORT RawPtrAsanBoundArgTracker {
 
   // When argument is base::Unretained, add the argument to the set of
   // arguments protected in this scope.
-  template <typename T, typename RawPtrType>
-  void AddArg(const internal::UnretainedWrapper<T, RawPtrType>& arg) {
+  template <typename T, typename UnretainedTrait, RawPtrTraits PtrTraits>
+  void AddArg(
+      const internal::UnretainedWrapper<T, UnretainedTrait, PtrTraits>& arg) {
     if constexpr (raw_ptr_traits::IsSupportedType<T>::value) {
-      Add(reinterpret_cast<uintptr_t>(arg.get()));
+      auto inner = arg.get();
+      // The argument may unwrap into a raw_ptr or a T* depending if it is
+      // allowed to dangle.
+      if constexpr (IsRawPtrV<decltype(inner)>) {
+        Add(reinterpret_cast<uintptr_t>(inner.get()));
+      } else {
+        Add(reinterpret_cast<uintptr_t>(inner));
+      }
     }
   }
 
   // When argument is a reference type that's supported by raw_ptr, add the
   // argument to the set of arguments protected in this scope.
-  template <typename T, typename RawPtrType, bool IsSupportedType>
+  template <typename T, typename UnretainedTrait, RawPtrTraits PtrTraits>
   void AddArg(
-      const internal::UnretainedRefWrapper<T, RawPtrType, IsSupportedType>&
+      const internal::UnretainedRefWrapper<T, UnretainedTrait, PtrTraits>&
           arg) {
-    if constexpr (IsSupportedType) {
+    if constexpr (raw_ptr_traits::IsSupportedType<T>::value) {
       Add(reinterpret_cast<uintptr_t>(&arg.get()));
     }
   }
@@ -94,10 +105,6 @@ class BASE_EXPORT RawPtrAsanBoundArgTracker {
     }
   }
 
-  static constexpr size_t kInlineArgsCount = 3;
-  using ProtectedArgsVector = base::StackVector<uintptr_t, kInlineArgsCount>;
-  static ThreadLocalPointer<ProtectedArgsVector>& CurrentProtectedArgs();
-
   // Cache whether or not BRP-ASan is running when we enter the argument
   // tracking scope so that we ensure that our actions on leaving the scope are
   // consistent even if the runtime flags are changed.
