@@ -1,4 +1,4 @@
-// Copyright (c) 2012 The Chromium Authors. All rights reserved.
+// Copyright 2012 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -167,9 +167,6 @@ struct MessagePumpGlib::RunState {
   // Used to flag that the current Run() invocation should return ASAP.
   bool should_quit;
 
-  // Used to count how many Run() invocations are on the stack.
-  int run_depth;
-
   // The information of the next task available at this run-level. Stored in
   // RunState because different set of tasks can be accessible at various
   // run-levels (e.g. non-nestable tasks).
@@ -234,8 +231,7 @@ bool MessagePumpGlib::FdWatchController::StopWatchingFileDescriptor() {
     return false;
 
   g_source_destroy(source_);
-  g_source_unref(source_);
-  source_ = nullptr;
+  g_source_unref(source_.ExtractAsDangling());
   watcher_ = nullptr;
   return true;
 }
@@ -378,7 +374,6 @@ void MessagePumpGlib::Run(Delegate* delegate) {
   RunState state;
   state.delegate = delegate;
   state.should_quit = false;
-  state.run_depth = state_ ? state_->run_depth + 1 : 1;
 
   RunState* previous_state = state_;
   state_ = &state;
