@@ -6,6 +6,7 @@
 
 #include <mach/mach.h>
 #include <stddef.h>
+#include <sys/resource.h>
 #include <sys/sysctl.h>
 #include <sys/time.h>
 #include <unistd.h>
@@ -17,14 +18,47 @@
 #include "base/feature_list.h"
 #include "base/mac/mach_logging.h"
 #include "base/memory/free_deleter.h"
+#include "third_party/abseil-cpp/absl/types/optional.h"
 
 namespace base {
 
-// Enables backgrounding hidden renderers on Mac.
-BASE_FEATURE(kMacAllowBackgroundingProcesses,
-             "MacAllowBackgroundingProcesses",
+namespace {
+
+// Enables setting the task role of every child process to
+// TASK_DEFAULT_APPLICATION.
+BASE_FEATURE(kMacSetDefaultTaskRole,
+             "MacSetDefaultTaskRole",
              FEATURE_DISABLED_BY_DEFAULT);
 
+// Returns the `task_role_t` of the process whose process ID is `pid`.
+absl::optional<task_role_t> GetTaskCategoryPolicyRole(
+    PortProvider* port_provider,
+    ProcessId pid) {
+  DCHECK(port_provider);
+
+  mach_port_t task_port = port_provider->TaskForPid(pid);
+  if (task_port == TASK_NULL) {
+    return absl::nullopt;
+  }
+
+  task_category_policy_data_t category_policy;
+  mach_msg_type_number_t task_info_count = TASK_CATEGORY_POLICY_COUNT;
+  boolean_t get_default = FALSE;
+
+  kern_return_t result =
+      task_policy_get(task_port, TASK_CATEGORY_POLICY,
+                      reinterpret_cast<task_policy_t>(&category_policy),
+                      &task_info_count, &get_default);
+  if (result != KERN_SUCCESS) {
+    MACH_LOG(ERROR, result) << "task_policy_get TASK_CATEGORY_POLICY";
+    return absl::nullopt;
+  }
+  DCHECK(!get_default);
+  return category_policy.role;
+}
+
+}  // namespace
+
 Time Process::CreationTime() const {
   int mib[] = {CTL_KERN, KERN_PROC, KERN_PROC_PID, Pid()};
   size_t len = 0;
@@ -39,47 +73,44 @@ Time Process::CreationTime() const {
 }
 
 bool Process::CanBackgroundProcesses() {
-  return FeatureList::IsEnabled(kMacAllowBackgroundingProcesses);
+  return true;
 }
 
 bool Process::IsProcessBackgrounded(PortProvider* port_provider) const {
   DCHECK(IsValid());
-  if (port_provider == nullptr)
-    return false;
+  DCHECK(port_provider);
 
-  mach_port_t task_port = port_provider->TaskForPid(Pid());
-  if (task_port == TASK_NULL)
-    return false;
-
-  task_category_policy_data_t category_policy;
-  mach_msg_type_number_t task_info_count = TASK_CATEGORY_POLICY_COUNT;
-  boolean_t get_default = FALSE;
-
-  kern_return_t result =
-      task_policy_get(task_port, TASK_CATEGORY_POLICY,
-                      reinterpret_cast<task_policy_t>(&category_policy),
-                      &task_info_count, &get_default);
-  MACH_LOG_IF(ERROR, result != KERN_SUCCESS, result)
-      << "task_policy_get TASK_CATEGORY_POLICY";
-
-  if (result == KERN_SUCCESS && get_default == FALSE) {
-    return category_policy.role == TASK_BACKGROUND_APPLICATION;
-  }
-  return false;
+  // A process is backgrounded if the role is explicitly
+  // TASK_BACKGROUND_APPLICATION (as opposed to not being
+  // TASK_FOREGROUND_APPLICATION).
+  absl::optional<task_role_t> task_role =
+      GetTaskCategoryPolicyRole(port_provider, Pid());
+  return task_role && *task_role == TASK_BACKGROUND_APPLICATION;
 }
 
 bool Process::SetProcessBackgrounded(PortProvider* port_provider,
                                      bool background) {
   DCHECK(IsValid());
-  if (port_provider == nullptr || !CanBackgroundProcesses())
+  DCHECK(port_provider);
+
+  if (!CanBackgroundProcesses()) {
     return false;
+  }
 
   mach_port_t task_port = port_provider->TaskForPid(Pid());
   if (task_port == TASK_NULL)
     return false;
 
-  if (IsProcessBackgrounded(port_provider) == background)
+  absl::optional<task_role_t> current_role =
+      GetTaskCategoryPolicyRole(port_provider, Pid());
+  if (!current_role) {
+    return false;
+  }
+
+  if ((background && *current_role == TASK_BACKGROUND_APPLICATION) ||
+      (!background && *current_role == TASK_FOREGROUND_APPLICATION)) {
     return true;
+  }
 
   task_category_policy category_policy;
   category_policy.role =
@@ -97,4 +128,17 @@ bool Process::SetProcessBackgrounded(PortProvider* port_provider,
   return true;
 }
 
+// static
+void Process::SetCurrentTaskDefaultRole() {
+  if (!base::FeatureList::IsEnabled(kMacSetDefaultTaskRole)) {
+    return;
+  }
+
+  task_category_policy category_policy;
+  category_policy.role = TASK_DEFAULT_APPLICATION;
+  task_policy_set(mach_task_self(), TASK_CATEGORY_POLICY,
+                  reinterpret_cast<task_policy_t>(&category_policy),
+                  TASK_CATEGORY_POLICY_COUNT);
+}
+
 }  // namespace base
