@@ -7,10 +7,12 @@
 
 #include <utility>
 
-#include "base/bind.h"
-#include "base/callback.h"
+#include "base/functional/bind.h"
+#include "base/functional/callback.h"
 #include "base/location.h"
 #include "base/path_service.h"
+#include "base/profiler/native_unwinder_android_map_delegate.h"
+#include "base/profiler/native_unwinder_android_memory_regions_map.h"
 #include "base/profiler/profiler_buildflags.h"
 #include "base/profiler/stack_buffer.h"
 #include "base/profiler/stack_sampling_profiler.h"
@@ -24,6 +26,7 @@
 #include "base/android/apk_assets.h"
 #include "base/android/library_loader/anchor_functions.h"
 #include "base/files/memory_mapped_file.h"
+#include "base/no_destructor.h"
 #include "base/profiler/chrome_unwinder_android.h"
 #include "base/profiler/native_unwinder_android.h"
 #endif
@@ -96,29 +99,36 @@ void OtherLibraryCallback(void* arg) {
 }
 
 #if BUILDFLAG(IS_ANDROID) && BUILDFLAG(ENABLE_ARM_CFI_TABLE)
+class NativeUnwinderAndroidMapDelegateForTesting
+    : public NativeUnwinderAndroidMapDelegate {
+ public:
+  explicit NativeUnwinderAndroidMapDelegateForTesting(
+      std::unique_ptr<NativeUnwinderAndroidMemoryRegionsMap> memory_regions_map)
+      : memory_regions_map_(std::move(memory_regions_map)) {}
+
+  NativeUnwinderAndroidMemoryRegionsMap* GetMapReference() override {
+    return memory_regions_map_.get();
+  }
+  void ReleaseMapReference() override {}
+
+ private:
+  const std::unique_ptr<NativeUnwinderAndroidMemoryRegionsMap>
+      memory_regions_map_;
+};
+
+// `map_delegate` should outlive the unwinder instance, so we cannot make a
+// derived `NativeUnwinderAndroidForTesting` to own the `map_delegate`, as
+// the base class outlives the derived class.
+NativeUnwinderAndroidMapDelegateForTesting* GetMapDelegateForTesting() {
+  static base::NoDestructor<NativeUnwinderAndroidMapDelegateForTesting>
+      map_delegate(NativeUnwinderAndroid::CreateMemoryRegionsMap());
+  return map_delegate.get();
+}
+
 std::unique_ptr<NativeUnwinderAndroid> CreateNativeUnwinderAndroidForTesting(
     uintptr_t exclude_module_with_base_address) {
-  class NativeUnwinderAndroidForTesting : public NativeUnwinderAndroid {
-   public:
-    explicit NativeUnwinderAndroidForTesting(
-        std::unique_ptr<unwindstack::Maps> memory_regions_map,
-        std::unique_ptr<unwindstack::Memory> process_memory,
-        uintptr_t exclude_module_with_base_address)
-        : NativeUnwinderAndroid(memory_regions_map.get(),
-                                process_memory.get(),
-                                exclude_module_with_base_address),
-          memory_regions_map_(std::move(memory_regions_map)),
-          process_memory_(std::move(process_memory)) {}
-    ~NativeUnwinderAndroidForTesting() override = default;
-
-   private:
-    std::unique_ptr<unwindstack::Maps> memory_regions_map_;
-    std::unique_ptr<unwindstack::Memory> process_memory_;
-  };
-  auto maps = NativeUnwinderAndroid::CreateMaps();
-  auto memory = NativeUnwinderAndroid::CreateProcessMemory();
-  return std::make_unique<NativeUnwinderAndroidForTesting>(
-      std::move(maps), std::move(memory), exclude_module_with_base_address);
+  return std::make_unique<NativeUnwinderAndroid>(
+      exclude_module_with_base_address, GetMapDelegateForTesting());
 }
 
 std::unique_ptr<Unwinder> CreateChromeUnwinderAndroidForTesting(
@@ -414,24 +424,24 @@ void ExpectStackDoesNotContain(
   }
 }
 
-NativeLibrary LoadOtherLibrary() {
+NativeLibrary LoadTestLibrary(StringPiece library_name) {
   // The lambda gymnastics works around the fact that we can't use ASSERT_*
   // macros in a function returning non-null.
-  const auto load = [](NativeLibrary* library) {
-    FilePath other_library_path;
+  const auto load = [&](NativeLibrary* library) {
+    FilePath library_path;
 #if BUILDFLAG(IS_FUCHSIA)
     // TODO(crbug.com/1262430): Find a solution that works across platforms.
-    ASSERT_TRUE(PathService::Get(DIR_ASSETS, &other_library_path));
+    ASSERT_TRUE(PathService::Get(DIR_ASSETS, &library_path));
 #else
     // The module is next to the test module rather than with test data.
-    ASSERT_TRUE(PathService::Get(DIR_MODULE, &other_library_path));
+    ASSERT_TRUE(PathService::Get(DIR_MODULE, &library_path));
 #endif  // BUILDFLAG(IS_FUCHSIA)
-    other_library_path = other_library_path.AppendASCII(
-        GetLoadableModuleName("base_profiler_test_support_library"));
+    library_path =
+        library_path.AppendASCII(GetLoadableModuleName(library_name));
     NativeLibraryLoadError load_error;
-    *library = LoadNativeLibrary(other_library_path, &load_error);
-    ASSERT_TRUE(*library) << "error loading " << other_library_path.value()
-                          << ": " << load_error.ToString();
+    *library = LoadNativeLibrary(library_path, &load_error);
+    ASSERT_TRUE(*library) << "error loading " << library_path.value() << ": "
+                          << load_error.ToString();
   };
 
   NativeLibrary library = nullptr;
@@ -439,6 +449,10 @@ NativeLibrary LoadOtherLibrary() {
   return library;
 }
 
+NativeLibrary LoadOtherLibrary() {
+  return LoadTestLibrary("base_profiler_test_support_library");
+}
+
 uintptr_t GetAddressInOtherLibrary(NativeLibrary library) {
   EXPECT_TRUE(library);
   uintptr_t address = reinterpret_cast<uintptr_t>(
