@@ -8,12 +8,14 @@
 #include <sched.h>
 #include <zircon/syscalls.h>
 
-#include <fuchsia/media/cpp/fidl.h>
+#include <mutex>
+
+#include <fidl/fuchsia.media/cpp/fidl.h>
 #include <lib/fdio/directory.h>
 #include <lib/sys/cpp/component_context.h>
 
+#include "base/fuchsia/fuchsia_component_connect.h"
 #include "base/fuchsia/fuchsia_logging.h"
-#include "base/fuchsia/process_context.h"
 #include "base/fuchsia/scheduler.h"
 #include "base/no_destructor.h"
 #include "base/threading/platform_thread_internal_posix.h"
@@ -24,19 +26,29 @@ namespace base {
 
 namespace {
 
-fuchsia::media::ProfileProviderSyncPtr ConnectProfileProvider() {
-  fuchsia::media::ProfileProviderSyncPtr profile_provider;
-  base::ComponentContextForProcess()->svc()->Connect(
-      profile_provider.NewRequest());
-  return profile_provider;
+fidl::SyncClient<fuchsia_media::ProfileProvider> ConnectProfileProvider() {
+  auto profile_provider_client_end =
+      base::fuchsia_component::Connect<fuchsia_media::ProfileProvider>();
+  if (profile_provider_client_end.is_error()) {
+    LOG(ERROR) << base::FidlConnectionErrorMessage(profile_provider_client_end);
+    return {};
+  }
+  return fidl::SyncClient(std::move(profile_provider_client_end.value()));
 }
 
-void ScheduleAsMediaThread(StringPiece name, TimeDelta period, float capacity) {
-  DCHECK(!period.is_zero());
-  DCHECK_GT(capacity, 0.0);
-  DCHECK_LT(capacity, 1.0);
+// Sets the current thread to the given scheduling role, optionally including
+// hints about the workload period and max CPU runtime (capacity * period) in
+// that period.
+// TODO(crbug.com/1365682): Migrate to the new fuchsia.scheduler.ProfileProvider
+// API when available.
+void SetThreadRole(StringPiece role_name,
+                   TimeDelta period = {},
+                   float capacity = 0.0f) {
+  DCHECK_GE(capacity, 0.0);
+  DCHECK_LE(capacity, 1.0);
 
-  static const base::NoDestructor<fuchsia::media::ProfileProviderSyncPtr>
+  static const base::NoDestructor<
+      fidl::SyncClient<fuchsia_media::ProfileProvider>>
       profile_provider(ConnectProfileProvider());
 
   zx::thread dup_thread;
@@ -44,16 +56,16 @@ void ScheduleAsMediaThread(StringPiece name, TimeDelta period, float capacity) {
       zx::thread::self()->duplicate(ZX_RIGHT_SAME_RIGHTS, &dup_thread);
   ZX_CHECK(status == ZX_OK, status) << "zx_object_duplicate";
 
-  int64_t out_period, out_capacity;
-  status = (*profile_provider)
-               ->RegisterHandlerWithCapacity(
-                   std::move(dup_thread), std::string(name),
-                   period.ToZxDuration(), capacity, &out_period, &out_capacity);
-
-  if (status != ZX_OK) {
-    ZX_LOG(WARNING, status)
-        << "Failed to register a realtime thread. Is "
-           "fuchsia.media.ProfileProvider in the component sandbox?";
+  std::string role_selector{role_name};
+  auto result = (*profile_provider)
+                    ->RegisterHandlerWithCapacity(
+                        {{.thread_handle = std::move(dup_thread),
+                          .name = role_selector,
+                          .period = period.ToZxDuration(),
+                          .capacity = capacity}});
+  if (result.is_error()) {
+    ZX_DLOG(ERROR, result.error_value().status())
+        << "Failed call to RegisterHandlerWithCapacity";
   }
 }
 
@@ -87,21 +99,36 @@ namespace internal {
 void SetCurrentThreadTypeImpl(ThreadType thread_type,
                               MessagePumpType pump_type_hint) {
   switch (thread_type) {
-    case ThreadType::kBackground:
-    case ThreadType::kResourceEfficient:
     case ThreadType::kDefault:
+      SetThreadRole("chromium.base.threading.default");
+
+      break;
+
+    case ThreadType::kBackground:
+      SetThreadRole("chromium.base.threading.background");
+      break;
+
+    case ThreadType::kUtility:
+      SetThreadRole("chromium.base.threading.utility");
+      break;
+
+    case ThreadType::kResourceEfficient:
+      SetThreadRole("chromium.base.threading.resource-efficient");
+      break;
+
     case ThreadType::kCompositing:
+      SetThreadRole("chromium.base.threading.compositing",
+                    kDisplaySchedulingPeriod, kDisplaySchedulingCapacity);
       break;
 
     case ThreadType::kDisplayCritical:
-      ScheduleAsMediaThread("chromium.base.threading.display",
-                            kDisplaySchedulingPeriod,
-                            kDisplaySchedulingCapacity);
+      SetThreadRole("chromium.base.threading.display", kDisplaySchedulingPeriod,
+                    kDisplaySchedulingCapacity);
       break;
 
     case ThreadType::kRealtimeAudio:
-      ScheduleAsMediaThread("chromium.base.threading.realtime-audio",
-                            kAudioSchedulingPeriod, kAudioSchedulingCapacity);
+      SetThreadRole("chromium.base.threading.realtime-audio",
+                    kAudioSchedulingPeriod, kAudioSchedulingCapacity);
       break;
   }
 }
@@ -115,6 +142,7 @@ ThreadPriorityForTest PlatformThread::GetCurrentThreadPriorityForTest() {
   const ThreadType thread_type = PlatformThread::GetCurrentThreadType();
   switch (thread_type) {
     case ThreadType::kBackground:
+    case ThreadType::kUtility:
     case ThreadType::kResourceEfficient:
     case ThreadType::kDefault:
     case ThreadType::kCompositing:
