@@ -11,6 +11,7 @@
 #include <vector>
 
 #include "base/logging.h"
+#include "base/metrics/histogram_functions.h"
 #include "base/numerics/checked_math.h"
 #include "base/strings/string_number_conversions.h"
 #include "base/strings/string_piece.h"
@@ -36,6 +37,13 @@ namespace crypto {
 
 namespace {
 
+const char kMetricVirtualCreateKeyError[] = "Crypto.TpmError.VirtualCreateKey";
+const char kMetricVirtualFinalizeKeyError[] =
+    "Crypto.TpmError.VirtualFinalizeKey";
+const char kMetricVirtualOpenKeyError[] = "Crypto.TpmError.VirtualOpenKey";
+const char kMetricVirtualOpenStorageError[] =
+    "Crypto.TpmError.VirtualOpenStorage";
+
 std::vector<uint8_t> CBBToVector(const CBB* cbb) {
   return std::vector<uint8_t>(CBB_data(cbb), CBB_data(cbb) + CBB_len(cbb));
 }
@@ -226,15 +234,73 @@ absl::optional<std::vector<uint8_t>> GetRSASPKI(NCRYPT_KEY_HANDLE key) {
   return CBBToVector(cbb.get());
 }
 
+absl::optional<std::vector<uint8_t>> SignECDSA(NCRYPT_KEY_HANDLE key,
+                                               base::span<const uint8_t> data) {
+  base::ScopedBlockingCall scoped_blocking_call(FROM_HERE,
+                                                base::BlockingType::WILL_BLOCK);
+
+  std::array<uint8_t, kSHA256Length> digest = SHA256Hash(data);
+  // The signature is written as a pair of big-endian field elements for P-256
+  // ECDSA.
+  std::vector<uint8_t> sig(64);
+  DWORD sig_size;
+  {
+    SCOPED_MAY_LOAD_LIBRARY_AT_BACKGROUND_PRIORITY();
+    if (FAILED(NCryptSignHash(key, nullptr, digest.data(), digest.size(),
+                              sig.data(), sig.size(), &sig_size,
+                              NCRYPT_SILENT_FLAG))) {
+      return absl::nullopt;
+    }
+  }
+  CHECK_EQ(sig.size(), sig_size);
+
+  bssl::UniquePtr<BIGNUM> r(BN_bin2bn(sig.data(), 32, nullptr));
+  bssl::UniquePtr<BIGNUM> s(BN_bin2bn(sig.data() + 32, 32, nullptr));
+  ECDSA_SIG sig_st;
+  sig_st.r = r.get();
+  sig_st.s = s.get();
+
+  bssl::ScopedCBB cbb;
+  CHECK(CBB_init(cbb.get(), /*initial_capacity=*/72) &&
+        ECDSA_SIG_marshal(cbb.get(), &sig_st));
+  return CBBToVector(cbb.get());
+}
+
+absl::optional<std::vector<uint8_t>> SignRSA(NCRYPT_KEY_HANDLE key,
+                                             base::span<const uint8_t> data) {
+  base::ScopedBlockingCall scoped_blocking_call(FROM_HERE,
+                                                base::BlockingType::WILL_BLOCK);
+
+  std::array<uint8_t, kSHA256Length> digest = SHA256Hash(data);
+  BCRYPT_PKCS1_PADDING_INFO padding_info = {0};
+  padding_info.pszAlgId = NCRYPT_SHA256_ALGORITHM;
+
+  DWORD sig_size;
+  SCOPED_MAY_LOAD_LIBRARY_AT_BACKGROUND_PRIORITY();
+  if (FAILED(NCryptSignHash(key, &padding_info, digest.data(), digest.size(),
+                            nullptr, 0, &sig_size,
+                            NCRYPT_SILENT_FLAG | BCRYPT_PAD_PKCS1))) {
+    return absl::nullopt;
+  }
+
+  std::vector<uint8_t> sig(sig_size);
+  if (FAILED(NCryptSignHash(key, &padding_info, digest.data(), digest.size(),
+                            sig.data(), sig.size(), &sig_size,
+                            NCRYPT_SILENT_FLAG | BCRYPT_PAD_PKCS1))) {
+    return absl::nullopt;
+  }
+  CHECK_EQ(sig.size(), sig_size);
+
+  return sig;
+}
+
 // ECDSAKey wraps a TPM-stored P-256 ECDSA key.
 class ECDSAKey : public UnexportableSigningKey {
  public:
-  ECDSAKey(ScopedNCryptProvider provider,
-           ScopedNCryptKey key,
+  ECDSAKey(ScopedNCryptKey key,
            std::vector<uint8_t> wrapped,
            std::vector<uint8_t> spki)
-      : provider_(std::move(provider)),
-        key_(std::move(key)),
+      : key_(std::move(key)),
         wrapped_(std::move(wrapped)),
         spki_(std::move(spki)) {}
 
@@ -250,38 +316,10 @@ class ECDSAKey : public UnexportableSigningKey {
 
   absl::optional<std::vector<uint8_t>> SignSlowly(
       base::span<const uint8_t> data) override {
-    base::ScopedBlockingCall scoped_blocking_call(
-        FROM_HERE, base::BlockingType::WILL_BLOCK);
-
-    std::array<uint8_t, kSHA256Length> digest = SHA256Hash(data);
-    // The signature is written as a pair of big-endian field elements for P-256
-    // ECDSA.
-    std::vector<uint8_t> sig(64);
-    DWORD sig_size;
-    {
-      SCOPED_MAY_LOAD_LIBRARY_AT_BACKGROUND_PRIORITY();
-      if (FAILED(NCryptSignHash(key_.get(), nullptr, digest.data(),
-                                digest.size(), sig.data(), sig.size(),
-                                &sig_size, NCRYPT_SILENT_FLAG))) {
-        return absl::nullopt;
-      }
-    }
-    CHECK_EQ(sig.size(), sig_size);
-
-    bssl::UniquePtr<BIGNUM> r(BN_bin2bn(sig.data(), 32, nullptr));
-    bssl::UniquePtr<BIGNUM> s(BN_bin2bn(sig.data() + 32, 32, nullptr));
-    ECDSA_SIG sig_st;
-    sig_st.r = r.get();
-    sig_st.s = s.get();
-
-    bssl::ScopedCBB cbb;
-    CHECK(CBB_init(cbb.get(), /*initial_capacity=*/72) &&
-          ECDSA_SIG_marshal(cbb.get(), &sig_st));
-    return CBBToVector(cbb.get());
+    return SignECDSA(key_.get(), data);
   }
 
  private:
-  ScopedNCryptProvider provider_;
   ScopedNCryptKey key_;
   const std::vector<uint8_t> wrapped_;
   const std::vector<uint8_t> spki_;
@@ -290,12 +328,10 @@ class ECDSAKey : public UnexportableSigningKey {
 // RSAKey wraps a TPM-stored RSA key.
 class RSAKey : public UnexportableSigningKey {
  public:
-  RSAKey(ScopedNCryptProvider provider,
-         ScopedNCryptKey key,
+  RSAKey(ScopedNCryptKey key,
          std::vector<uint8_t> wrapped,
          std::vector<uint8_t> spki)
-      : provider_(std::move(provider)),
-        key_(std::move(key)),
+      : key_(std::move(key)),
         wrapped_(std::move(wrapped)),
         spki_(std::move(spki)) {}
 
@@ -311,34 +347,10 @@ class RSAKey : public UnexportableSigningKey {
 
   absl::optional<std::vector<uint8_t>> SignSlowly(
       base::span<const uint8_t> data) override {
-    base::ScopedBlockingCall scoped_blocking_call(
-        FROM_HERE, base::BlockingType::WILL_BLOCK);
-
-    std::array<uint8_t, kSHA256Length> digest = SHA256Hash(data);
-    BCRYPT_PKCS1_PADDING_INFO padding_info = {0};
-    padding_info.pszAlgId = NCRYPT_SHA256_ALGORITHM;
-
-    DWORD sig_size;
-    SCOPED_MAY_LOAD_LIBRARY_AT_BACKGROUND_PRIORITY();
-    if (FAILED(NCryptSignHash(key_.get(), &padding_info, digest.data(),
-                              digest.size(), nullptr, 0, &sig_size,
-                              NCRYPT_SILENT_FLAG | BCRYPT_PAD_PKCS1))) {
-      return absl::nullopt;
-    }
-
-    std::vector<uint8_t> sig(sig_size);
-    if (FAILED(NCryptSignHash(key_.get(), &padding_info, digest.data(),
-                              digest.size(), sig.data(), sig.size(), &sig_size,
-                              NCRYPT_SILENT_FLAG | BCRYPT_PAD_PKCS1))) {
-      return absl::nullopt;
-    }
-    CHECK_EQ(sig.size(), sig_size);
-
-    return sig;
+    return SignRSA(key_.get(), data);
   }
 
  private:
-  ScopedNCryptProvider provider_;
   ScopedNCryptKey key_;
   const std::vector<uint8_t> wrapped_;
   const std::vector<uint8_t> spki_;
@@ -417,16 +429,14 @@ class UnexportableKeyProviderWin : public UnexportableKeyProvider {
         if (!spki) {
           return nullptr;
         }
-        return std::make_unique<ECDSAKey>(std::move(provider), std::move(key),
-                                          std::move(*wrapped_key),
-                                          std::move(spki.value()));
+        return std::make_unique<ECDSAKey>(
+            std::move(key), std::move(*wrapped_key), std::move(spki.value()));
       case SignatureVerifier::SignatureAlgorithm::RSA_PKCS1_SHA256:
         spki = GetRSASPKI(key.get());
         if (!spki) {
           return nullptr;
         }
-        return std::make_unique<RSAKey>(std::move(provider), std::move(key),
-                                        std::move(*wrapped_key),
+        return std::make_unique<RSAKey>(std::move(key), std::move(*wrapped_key),
                                         std::move(spki.value()));
       default:
         return nullptr;
@@ -477,8 +487,7 @@ class UnexportableKeyProviderWin : public UnexportableKeyProvider {
         return nullptr;
       }
       return std::make_unique<ECDSAKey>(
-          std::move(provider), std::move(key),
-          std::vector<uint8_t>(wrapped.begin(), wrapped.end()),
+          std::move(key), std::vector<uint8_t>(wrapped.begin(), wrapped.end()),
           std::move(spki.value()));
     } else if (algo_bytes->size() == sizeof(kRSA) &&
                memcmp(algo_bytes->data(), kRSA, sizeof(kRSA)) == 0) {
@@ -487,8 +496,7 @@ class UnexportableKeyProviderWin : public UnexportableKeyProvider {
         return nullptr;
       }
       return std::make_unique<RSAKey>(
-          std::move(provider), std::move(key),
-          std::vector<uint8_t>(wrapped.begin(), wrapped.end()),
+          std::move(key), std::vector<uint8_t>(wrapped.begin(), wrapped.end()),
           std::move(spki.value()));
     }
 
@@ -496,10 +504,254 @@ class UnexportableKeyProviderWin : public UnexportableKeyProvider {
   }
 };
 
+// ECDSASoftwareKey wraps a Credential Guard stored P-256 ECDSA key.
+class ECDSASoftwareKey : public VirtualUnexportableSigningKey {
+ public:
+  ECDSASoftwareKey(ScopedNCryptKey key,
+                   std::string name,
+                   std::vector<uint8_t> spki)
+      : key_(std::move(key)), name_(std::move(name)), spki_(std::move(spki)) {}
+
+  SignatureVerifier::SignatureAlgorithm Algorithm() const override {
+    return SignatureVerifier::SignatureAlgorithm::ECDSA_SHA256;
+  }
+
+  std::vector<uint8_t> GetSubjectPublicKeyInfo() const override {
+    return spki_;
+  }
+
+  std::string GetKeyName() const override { return name_; }
+
+  absl::optional<std::vector<uint8_t>> Sign(
+      base::span<const uint8_t> data) override {
+    if (!valid_) {
+      return absl::nullopt;
+    }
+
+    return SignECDSA(key_.get(), data);
+  }
+
+  bool DeleteKey() override {
+    if (!valid_) {
+      return false;
+    }
+
+    auto status = NCryptDeleteKey(key_.get(), NCRYPT_SILENT_FLAG);
+    valid_ = false;
+    return !FAILED(status);
+  }
+
+ private:
+  ScopedNCryptKey key_;
+  const std::string name_;
+  const std::vector<uint8_t> spki_;
+  bool valid_ = true;
+};
+
+// RSASoftwareKey wraps a Credential Guard stored RSA key.
+class RSASoftwareKey : public VirtualUnexportableSigningKey {
+ public:
+  RSASoftwareKey(ScopedNCryptKey key,
+                 std::string name,
+                 std::vector<uint8_t> spki)
+      : key_(std::move(key)), name_(std::move(name)), spki_(std::move(spki)) {}
+
+  SignatureVerifier::SignatureAlgorithm Algorithm() const override {
+    return SignatureVerifier::SignatureAlgorithm::RSA_PKCS1_SHA256;
+  }
+
+  std::vector<uint8_t> GetSubjectPublicKeyInfo() const override {
+    return spki_;
+  }
+
+  std::string GetKeyName() const override { return name_; }
+
+  absl::optional<std::vector<uint8_t>> Sign(
+      base::span<const uint8_t> data) override {
+    if (!valid_) {
+      return absl::nullopt;
+    }
+
+    return SignRSA(key_.get(), data);
+  }
+
+  bool DeleteKey() override {
+    if (!valid_) {
+      return false;
+    }
+
+    auto status = NCryptDeleteKey(key_.get(), NCRYPT_SILENT_FLAG);
+    valid_ = false;
+    return !FAILED(status);
+  }
+
+ private:
+  ScopedNCryptKey key_;
+  std::string name_;
+  const std::vector<uint8_t> spki_;
+  bool valid_ = true;
+};
+
+// UnexportableKeyProviderWin uses NCrypt and the Platform Crypto
+// Provider to expose Credential Guard backed keys on Windows.
+class VirtualUnexportableKeyProviderWin
+    : public VirtualUnexportableKeyProvider {
+ public:
+  ~VirtualUnexportableKeyProviderWin() override = default;
+
+  absl::optional<SignatureVerifier::SignatureAlgorithm> SelectAlgorithm(
+      base::span<const SignatureVerifier::SignatureAlgorithm>
+          acceptable_algorithms) override {
+    ScopedNCryptProvider provider;
+    {
+      SCOPED_MAY_LOAD_LIBRARY_AT_BACKGROUND_PRIORITY();
+      SECURITY_STATUS status = NCryptOpenStorageProvider(
+          ScopedNCryptProvider::Receiver(provider).get(),
+          MS_KEY_STORAGE_PROVIDER, /*dwFlags=*/0);
+      if (FAILED(status)) {
+        base::UmaHistogramSparse(kMetricVirtualOpenStorageError, status);
+        return absl::nullopt;
+      }
+    }
+
+    return GetBestSupported(provider.get(), acceptable_algorithms);
+  }
+
+  std::unique_ptr<VirtualUnexportableSigningKey> GenerateSigningKey(
+      base::span<const SignatureVerifier::SignatureAlgorithm>
+          acceptable_algorithms,
+      std::string name) override {
+    base::ScopedBlockingCall scoped_blocking_call(
+        FROM_HERE, base::BlockingType::WILL_BLOCK);
+
+    ScopedNCryptProvider provider;
+    {
+      SCOPED_MAY_LOAD_LIBRARY_AT_BACKGROUND_PRIORITY();
+      SECURITY_STATUS status = NCryptOpenStorageProvider(
+          ScopedNCryptProvider::Receiver(provider).get(),
+          MS_KEY_STORAGE_PROVIDER, /*dwFlags=*/0);
+      if (FAILED(status)) {
+        base::UmaHistogramSparse(kMetricVirtualOpenStorageError, status);
+        return nullptr;
+      }
+    }
+
+    absl::optional<SignatureVerifier::SignatureAlgorithm> algo =
+        GetBestSupported(provider.get(), acceptable_algorithms);
+    if (!algo) {
+      return nullptr;
+    }
+
+    ScopedNCryptKey key;
+    {
+      SCOPED_MAY_LOAD_LIBRARY_AT_BACKGROUND_PRIORITY();
+      // An empty key name stops the key being persisted to disk.
+      SECURITY_STATUS status = NCryptCreatePersistedKey(
+          provider.get(), ScopedNCryptKey::Receiver(key).get(),
+          BCryptAlgorithmFor(*algo).value(), base::SysUTF8ToWide(name).c_str(),
+          /*dwLegacyKeySpec=*/0,
+          /*dwFlags=*/NCRYPT_USE_VIRTUAL_ISOLATION_FLAG);
+      if (FAILED(status)) {
+        base::UmaHistogramSparse(kMetricVirtualCreateKeyError, status);
+        return nullptr;
+      }
+
+      status = NCryptFinalizeKey(
+          key.get(), NCRYPT_PROTECT_TO_LOCAL_SYSTEM | NCRYPT_SILENT_FLAG);
+      if (FAILED(status)) {
+        base::UmaHistogramSparse(kMetricVirtualFinalizeKeyError, status);
+        return nullptr;
+      }
+    }
+
+    absl::optional<std::vector<uint8_t>> spki;
+    switch (*algo) {
+      case SignatureVerifier::SignatureAlgorithm::ECDSA_SHA256:
+        spki = GetP256ECDSASPKI(key.get());
+        if (!spki) {
+          return nullptr;
+        }
+        return std::make_unique<ECDSASoftwareKey>(std::move(key), name,
+                                                  std::move(spki.value()));
+      case SignatureVerifier::SignatureAlgorithm::RSA_PKCS1_SHA256:
+        spki = GetRSASPKI(key.get());
+        if (!spki) {
+          return nullptr;
+        }
+        return std::make_unique<RSASoftwareKey>(std::move(key), name,
+                                                std::move(spki.value()));
+      default:
+        return nullptr;
+    }
+  }
+
+  std::unique_ptr<VirtualUnexportableSigningKey> FromKeyName(
+      std::string name) override {
+    base::ScopedBlockingCall scoped_blocking_call(
+        FROM_HERE, base::BlockingType::WILL_BLOCK);
+
+    ScopedNCryptProvider provider;
+    ScopedNCryptKey key;
+    {
+      SCOPED_MAY_LOAD_LIBRARY_AT_BACKGROUND_PRIORITY();
+      SECURITY_STATUS status = NCryptOpenStorageProvider(
+          ScopedNCryptProvider::Receiver(provider).get(),
+          MS_KEY_STORAGE_PROVIDER, /*dwFlags=*/0);
+      if (FAILED(status)) {
+        base::UmaHistogramSparse(kMetricVirtualOpenStorageError, status);
+        return nullptr;
+      }
+
+      status = NCryptOpenKey(
+          provider.get(), ScopedNCryptKey::Receiver(key).get(),
+          base::SysUTF8ToWide(name).c_str(), /*dwLegacyKeySpec=*/0,
+          /*dwFlags*/ 0);
+      if (FAILED(status)) {
+        base::UmaHistogramSparse(kMetricVirtualOpenKeyError, status);
+        return nullptr;
+      }
+    }
+
+    const absl::optional<std::vector<uint8_t>> algo_bytes =
+        GetKeyProperty(key.get(), NCRYPT_ALGORITHM_PROPERTY);
+
+    // This is the expected behavior, but note it is different from
+    // TPM backed keys.
+    static const wchar_t kECDSA[] = BCRYPT_ECDSA_P256_ALGORITHM;
+    static const wchar_t kRSA[] = BCRYPT_RSA_ALGORITHM;
+
+    absl::optional<std::vector<uint8_t>> spki;
+    if (algo_bytes->size() == sizeof(kECDSA) &&
+        memcmp(algo_bytes->data(), kECDSA, sizeof(kECDSA)) == 0) {
+      spki = GetP256ECDSASPKI(key.get());
+      if (!spki) {
+        return nullptr;
+      }
+      return std::make_unique<ECDSASoftwareKey>(std::move(key), name,
+                                                std::move(spki.value()));
+    } else if (algo_bytes->size() == sizeof(kRSA) &&
+               memcmp(algo_bytes->data(), kRSA, sizeof(kRSA)) == 0) {
+      spki = GetRSASPKI(key.get());
+      if (!spki) {
+        return nullptr;
+      }
+      return std::make_unique<RSASoftwareKey>(std::move(key), name,
+                                              std::move(spki.value()));
+    }
+
+    return nullptr;
+  }
+};
+
 }  // namespace
 
 std::unique_ptr<UnexportableKeyProvider> GetUnexportableKeyProviderWin() {
   return std::make_unique<UnexportableKeyProviderWin>();
 }
 
+std::unique_ptr<VirtualUnexportableKeyProvider>
+GetVirtualUnexportableKeyProviderWin() {
+  return std::make_unique<VirtualUnexportableKeyProviderWin>();
+}
+
 }  // namespace crypto
