@@ -1,4 +1,4 @@
-// Copyright (c) 2012 The Chromium Authors. All rights reserved.
+// Copyright 2012 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -152,6 +152,15 @@ bool GetNetworkListImpl(NetworkInterfaceList* networks,
       continue;
     }
 
+    absl::optional<Eui48MacAddress> mac_address;
+    mac_address.emplace();
+    if (adapter->PhysicalAddressLength == mac_address->size()) {
+      std::copy_n(reinterpret_cast<const uint8_t*>(adapter->PhysicalAddress),
+                  mac_address->size(), mac_address->begin());
+    } else {
+      mac_address.reset();
+    }
+
     for (IP_ADAPTER_UNICAST_ADDRESS* address = adapter->FirstUnicastAddress;
          address; address = address->Next) {
       int family = address->Address.lpSockaddr->sa_family;
@@ -188,7 +197,7 @@ bool GetNetworkListImpl(NetworkInterfaceList* networks,
               adapter->AdapterName,
               base::SysWideToNativeMB(adapter->FriendlyName), index,
               GetNetworkInterfaceType(adapter->IfType), endpoint.address(),
-              prefix_length, ip_address_attributes));
+              prefix_length, ip_address_attributes, mac_address));
         }
       }
     }
