@@ -54,27 +54,28 @@ namespace {
 // ReadHeader reads the header (including length prefix) from |data| and
 // updates |data| to remove the header on return. Caller takes ownership of the
 // returned pointer.
-std::unique_ptr<base::Value> ReadHeader(base::StringPiece* data) {
+absl::optional<base::Value> ReadHeader(base::StringPiece* data) {
   uint16_t header_len;
-  if (data->size() < sizeof(header_len))
-    return nullptr;
+  if (data->size() < sizeof(header_len)) {
+    return absl::nullopt;
+  }
   // Assumes little-endian.
   memcpy(&header_len, data->data(), sizeof(header_len));
   data->remove_prefix(sizeof(header_len));
 
-  if (data->size() < header_len)
-    return nullptr;
+  if (data->size() < header_len) {
+    return absl::nullopt;
+  }
 
   const base::StringPiece header_bytes = data->substr(0, header_len);
   data->remove_prefix(header_len);
 
-  std::unique_ptr<base::Value> header = base::JSONReader::ReadDeprecated(
-      header_bytes, base::JSON_ALLOW_TRAILING_COMMAS);
-  if (header.get() == nullptr)
-    return nullptr;
+  absl::optional<base::Value> header =
+      base::JSONReader::Read(header_bytes, base::JSON_ALLOW_TRAILING_COMMAS);
+  if (!header || !header->is_dict()) {
+    return absl::nullopt;
+  }
 
-  if (!header->is_dict())
-    return nullptr;
   return header;
 }
 
@@ -214,9 +215,10 @@ bool CRLSet::Parse(base::StringPiece data, scoped_refptr<CRLSet>* out_crl_set) {
 #error assumes little endian
 #endif
 
-  std::unique_ptr<base::Value> header_value(ReadHeader(&data));
-  if (!header_value.get())
+  absl::optional<base::Value> header_value = ReadHeader(&data);
+  if (!header_value) {
     return false;
+  }
 
   const base::Value::Dict& header_dict = header_value->GetDict();
 
