@@ -122,8 +122,7 @@ int TrustAndKeyIdentifierMatchToOrder(const ParsedCertificate* target,
   KeyIdentifierMatch key_id_match = CalculateKeyIdentifierMatch(target, issuer);
   switch (issuer_trust.type) {
     case CertificateTrustType::TRUSTED_ANCHOR:
-    case CertificateTrustType::TRUSTED_ANCHOR_WITH_EXPIRATION:
-    case CertificateTrustType::TRUSTED_ANCHOR_WITH_CONSTRAINTS:
+    case CertificateTrustType::TRUSTED_ANCHOR_OR_LEAF:
       switch (key_id_match) {
         case kMatch:
           return kTrustedAndKeyIdMatch;
@@ -133,6 +132,7 @@ int TrustAndKeyIdentifierMatchToOrder(const ParsedCertificate* target,
           return kTrustedAndKeyIdMismatch;
       }
     case CertificateTrustType::UNSPECIFIED:
+    case CertificateTrustType::TRUSTED_LEAF:
       switch (key_id_match) {
         case kMatch:
           return kKeyIdMatch;
@@ -161,7 +161,7 @@ class CertIssuersIter {
   // and |*debug_data| must be valid for the lifetime of the CertIssuersIter.
   CertIssuersIter(std::shared_ptr<const ParsedCertificate> cert,
                   CertIssuerSources* cert_issuer_sources,
-                  const TrustStore* trust_store,
+                  TrustStore* trust_store,
                   base::SupportsUserData* debug_data);
 
   CertIssuersIter(const CertIssuersIter&) = delete;
@@ -197,7 +197,7 @@ class CertIssuersIter {
 
   std::shared_ptr<const ParsedCertificate> cert_;
   CertIssuerSources* cert_issuer_sources_;
-  const TrustStore* trust_store_;
+  TrustStore* trust_store_;
 
   // The list of issuers for |cert_|. This is added to incrementally (first
   // synchronous results, then possibly multiple times as asynchronous results
@@ -237,7 +237,7 @@ class CertIssuersIter {
 CertIssuersIter::CertIssuersIter(
     std::shared_ptr<const ParsedCertificate> in_cert,
     CertIssuerSources* cert_issuer_sources,
-    const TrustStore* trust_store,
+    TrustStore* trust_store,
     base::SupportsUserData* debug_data)
     : cert_(in_cert),
       cert_issuer_sources_(cert_issuer_sources),
@@ -444,8 +444,8 @@ const ParsedCertificate* CertPathBuilderResultPath::GetTrustedCert() const {
 
   switch (last_cert_trust.type) {
     case CertificateTrustType::TRUSTED_ANCHOR:
-    case CertificateTrustType::TRUSTED_ANCHOR_WITH_EXPIRATION:
-    case CertificateTrustType::TRUSTED_ANCHOR_WITH_CONSTRAINTS:
+    case CertificateTrustType::TRUSTED_ANCHOR_OR_LEAF:
+    case CertificateTrustType::TRUSTED_LEAF:
       return certs.back().get();
     case CertificateTrustType::UNSPECIFIED:
     case CertificateTrustType::DISTRUSTED:
@@ -462,7 +462,7 @@ const ParsedCertificate* CertPathBuilderResultPath::GetTrustedCert() const {
 class CertPathIter {
  public:
   CertPathIter(std::shared_ptr<const ParsedCertificate> cert,
-               const TrustStore* trust_store,
+               TrustStore* trust_store,
                base::SupportsUserData* debug_data);
 
   CertPathIter(const CertPathIter&) = delete;
@@ -501,13 +501,13 @@ class CertPathIter {
   // The CertIssuerSources for retrieving candidate issuers.
   CertIssuerSources cert_issuer_sources_;
   // The TrustStore for checking if a path ends in a trust anchor.
-  const TrustStore* trust_store_;
+  TrustStore* trust_store_;
 
   base::SupportsUserData* debug_data_;
 };
 
 CertPathIter::CertPathIter(std::shared_ptr<const ParsedCertificate> cert,
-                           const TrustStore* trust_store,
+                           TrustStore* trust_store,
                            base::SupportsUserData* debug_data)
     : trust_store_(trust_store), debug_data_(debug_data) {
   // Initialize |next_issuer_| to the target certificate.
@@ -594,18 +594,50 @@ bool CertPathIter::GetNextPath(ParsedCertificateList* out_certs,
       }
     }
 
-    // If the cert is trusted but is the leaf, treat it as having unspecified
-    // trust. This may allow a successful path to be built to a different root
-    // (or to the same cert if it's self-signed).
+    // Overrides for cert with trust appearing in the wrong place for the type
+    // of trust (trusted leaf in non-leaf position, or trust anchor in leaf
+    // position.)
     switch (next_issuer_.trust.type) {
       case CertificateTrustType::TRUSTED_ANCHOR:
-      case CertificateTrustType::TRUSTED_ANCHOR_WITH_EXPIRATION:
-      case CertificateTrustType::TRUSTED_ANCHOR_WITH_CONSTRAINTS:
+        // If the leaf cert is trusted only as an anchor, treat it as having
+        // unspecified trust. This may allow a successful path to be built to a
+        // different root (or to the same cert if it's self-signed).
         if (cur_path_.Empty()) {
           DVLOG(1) << "Leaf is a trust anchor, considering as UNSPECIFIED";
           next_issuer_.trust = CertificateTrust::ForUnspecified();
         }
         break;
+      case CertificateTrustType::TRUSTED_LEAF:
+        // If a non-leaf cert is trusted only as a leaf, treat it as having
+        // unspecified trust. This may allow a successful path to be built to a
+        // trusted root.
+        if (!cur_path_.Empty()) {
+          DVLOG(1) << "Issuer is a trust leaf, considering as UNSPECIFIED";
+          next_issuer_.trust = CertificateTrust::ForUnspecified();
+        }
+        break;
+      case CertificateTrustType::DISTRUSTED:
+      case CertificateTrustType::UNSPECIFIED:
+      case CertificateTrustType::TRUSTED_ANCHOR_OR_LEAF:
+        // No override necessary.
+        break;
+    }
+
+    // Overrides for trusted leaf cert with require_leaf_selfsigned. If the leaf
+    // isn't actually self-signed, treat it as unspecified.
+    switch (next_issuer_.trust.type) {
+      case CertificateTrustType::TRUSTED_LEAF:
+      case CertificateTrustType::TRUSTED_ANCHOR_OR_LEAF:
+        if (cur_path_.Empty() && next_issuer_.trust.require_leaf_selfsigned &&
+            !VerifyCertificateIsSelfSigned(*next_issuer_.cert,
+                                           delegate->GetVerifyCache(),
+                                           /*errors=*/nullptr)) {
+          DVLOG(1) << "Leaf is trusted with require_leaf_selfsigned but is "
+                      "not self-signed, considering as UNSPECIFIED";
+          next_issuer_.trust = CertificateTrust::ForUnspecified();
+        }
+        break;
+      case CertificateTrustType::TRUSTED_ANCHOR:
       case CertificateTrustType::DISTRUSTED:
       case CertificateTrustType::UNSPECIFIED:
         // No override necessary.
@@ -618,8 +650,8 @@ bool CertPathIter::GetNextPath(ParsedCertificateList* out_certs,
       // path.
       case CertificateTrustType::DISTRUSTED:
       case CertificateTrustType::TRUSTED_ANCHOR:
-      case CertificateTrustType::TRUSTED_ANCHOR_WITH_EXPIRATION:
-      case CertificateTrustType::TRUSTED_ANCHOR_WITH_CONSTRAINTS: {
+      case CertificateTrustType::TRUSTED_ANCHOR_OR_LEAF:
+      case CertificateTrustType::TRUSTED_LEAF: {
         // If the issuer has a known trust level, can stop building the path.
         DVLOG(2) << "CertPathIter got anchor: "
                  << CertDebugString(next_issuer_.cert.get());
