@@ -12,8 +12,11 @@
 #include "net/cert/pki/cert_errors.h"
 #include "net/cert/pki/simple_path_builder_delegate.h"
 #include "net/cert/pki/string_util.h"
+#include "net/cert/pki/trust_store.h"
 #include "net/der/parser.h"
 #include "testing/gtest/include/gtest/gtest.h"
+#include "third_party/boringssl/src/include/openssl/bytestring.h"
+#include "third_party/boringssl/src/include/openssl/mem.h"
 #include "third_party/boringssl/src/include/openssl/pool.h"
 
 #include <sstream>
@@ -39,6 +42,54 @@ bool GetValue(std::string_view prefix,
   return true;
 }
 
+// Returns a string containing the dotted numeric form of |oid|, or a
+// hex-encoded string on error.
+std::string OidToString(der::Input oid) {
+  CBS cbs;
+  CBS_init(&cbs, oid.UnsafeData(), oid.Length());
+  bssl::UniquePtr<char> text(CBS_asn1_oid_to_text(&cbs));
+  if (!text) {
+    return "invalid:" +
+           net::string_util::HexEncode(oid.UnsafeData(), oid.Length());
+  }
+  return text.get();
+}
+
+std::string StrSetToString(const std::set<std::string>& str_set) {
+  std::string out;
+  for (const auto& s : str_set) {
+    EXPECT_FALSE(s.empty());
+    if (!out.empty()) {
+      out += ", ";
+    }
+    out += s;
+  }
+  return out;
+}
+
+std::string_view StripString(std::string_view str) {
+  size_t start = str.find_first_not_of(' ');
+  if (start == str.npos) {
+    return std::string_view();
+  }
+  str = str.substr(start);
+  size_t end = str.find_last_not_of(' ');
+  if (end != str.npos) {
+    ++end;
+  }
+  return str.substr(0, end);
+}
+
+std::vector<std::string_view> SplitString(std::string_view str) {
+  std::vector<std::string_view> split = string_util::SplitString(str, ',');
+
+  std::vector<std::string_view> out;
+  for (const auto& s : split) {
+    out.push_back(StripString(s));
+  }
+  return out;
+}
+
 }  // namespace
 
 namespace der {
@@ -194,6 +245,7 @@ bool ReadVerifyCertChainTestFromFile(const std::string& file_path_ascii,
   bool has_errors = false;
   bool has_key_purpose = false;
   bool has_digest_policy = false;
+  bool has_user_constrained_policy_set = false;
 
   std::string kExpectedErrors = "expected_errors:";
 
@@ -252,14 +304,35 @@ bool ReadVerifyCertChainTestFromFile(const std::string& file_path_ascii,
         return false;
       }
     } else if (GetValue("last_cert_trust: ", line_piece, &value, &has_trust)) {
+      // TODO(mattm): convert test files to use
+      // CertificateTrust::FromDebugString strings.
       if (value == "TRUSTED_ANCHOR") {
         test->last_cert_trust = CertificateTrust::ForTrustAnchor();
       } else if (value == "TRUSTED_ANCHOR_WITH_EXPIRATION") {
         test->last_cert_trust =
-            CertificateTrust::ForTrustAnchorEnforcingExpiration();
+            CertificateTrust::ForTrustAnchor().WithEnforceAnchorExpiry();
       } else if (value == "TRUSTED_ANCHOR_WITH_CONSTRAINTS") {
         test->last_cert_trust =
-            CertificateTrust::ForTrustAnchorEnforcingConstraints();
+            CertificateTrust::ForTrustAnchor().WithEnforceAnchorConstraints();
+      } else if (value == "TRUSTED_ANCHOR_WITH_REQUIRE_BASIC_CONSTRAINTS") {
+        test->last_cert_trust = CertificateTrust::ForTrustAnchor()
+                                    .WithRequireAnchorBasicConstraints();
+      } else if (value ==
+                 "TRUSTED_ANCHOR_WITH_CONSTRAINTS_REQUIRE_BASIC_CONSTRAINTS") {
+        test->last_cert_trust = CertificateTrust::ForTrustAnchor()
+                                    .WithEnforceAnchorConstraints()
+                                    .WithRequireAnchorBasicConstraints();
+      } else if (value == "TRUSTED_ANCHOR_WITH_EXPIRATION_AND_CONSTRAINTS") {
+        test->last_cert_trust = CertificateTrust::ForTrustAnchor()
+                                    .WithEnforceAnchorExpiry()
+                                    .WithEnforceAnchorConstraints();
+      } else if (value == "TRUSTED_ANCHOR_OR_LEAF") {
+        test->last_cert_trust = CertificateTrust::ForTrustAnchorOrLeaf();
+      } else if (value == "TRUSTED_LEAF") {
+        test->last_cert_trust = CertificateTrust::ForTrustedLeaf();
+      } else if (value == "TRUSTED_LEAF_REQUIRE_SELF_SIGNED") {
+        test->last_cert_trust =
+            CertificateTrust::ForTrustedLeaf().WithRequireLeafSelfSigned();
       } else if (value == "DISTRUSTED") {
         test->last_cert_trust = CertificateTrust::ForDistrusted();
       } else if (value == "UNSPECIFIED") {
@@ -279,6 +352,11 @@ bool ReadVerifyCertChainTestFromFile(const std::string& file_path_ascii,
         ADD_FAILURE() << "Unrecognized digest_policy: " << value;
         return false;
       }
+    } else if (GetValue("expected_user_constrained_policy_set: ", line_piece,
+                        &value, &has_user_constrained_policy_set)) {
+      std::vector<std::string_view> split_value(SplitString(value));
+      test->expected_user_constrained_policy_set =
+          std::set<std::string>(split_value.begin(), split_value.end());
     } else if (net::string_util::StartsWith(line_piece, "#")) {
       // Skip comments.
       continue;
@@ -326,6 +404,10 @@ bool ReadVerifyCertChainTestFromFile(const std::string& file_path_ascii,
     return false;
   }
 
+  // `has_user_constrained_policy_set` is intentionally not checked here. Not
+  // specifying expected_user_constrained_policy_set means the expected policy
+  // set is empty.
+
   return true;
 }
 
@@ -382,4 +464,25 @@ void VerifyCertErrors(const std::string& expected_errors_str,
   }
 }
 
+void VerifyUserConstrainedPolicySet(
+    const std::set<std::string>& expected_user_constrained_policy_str_set,
+    const std::set<der::Input>& actual_user_constrained_policy_set,
+    const std::string& errors_file_path) {
+  std::set<std::string> actual_user_constrained_policy_str_set;
+  for (const auto der_oid : actual_user_constrained_policy_set) {
+    actual_user_constrained_policy_str_set.insert(OidToString(der_oid));
+  }
+  if (expected_user_constrained_policy_str_set !=
+      actual_user_constrained_policy_str_set) {
+    ADD_FAILURE() << "user_constrained_policy_set doesn't match expectations ("
+                  << errors_file_path << ")\n\n"
+                  << "EXPECTED: "
+                  << StrSetToString(expected_user_constrained_policy_str_set)
+                  << "\n"
+                  << "ACTUAL: "
+                  << StrSetToString(actual_user_constrained_policy_str_set)
+                  << "\n";
+  }
+}
+
 }  // namespace net
