@@ -1,4 +1,4 @@
-// Copyright 2018 The Chromium Authors. All rights reserved.
+// Copyright 2018 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -146,6 +146,10 @@ struct NET_EXPORT CookieDeletionInfo {
   // all partitions.
   CookiePartitionKeyCollection cookie_partition_key_collection =
       CookiePartitionKeyCollection::ContainsAll();
+
+  // If true, third-party cookie blocking applies to the context that triggered
+  // the deletion. In this case, we should only delete partitioned cookies.
+  bool partitioned_state_only = false;
 };
 
 }  // namespace net
