@@ -8,6 +8,7 @@
 #define NET_COOKIES_COOKIE_OPTIONS_H_
 
 #include <ostream>
+#include <string>
 
 #include "net/base/net_export.h"
 #include "net/cookies/cookie_constants.h"
@@ -88,6 +89,26 @@ class NET_EXPORT CookieOptions {
         kMaxValue = kAllSameSiteRedirect
       };
 
+      // These values are persisted to logs. Entries should not be renumbered
+      // and numeric values should never be reused.
+      enum class HttpMethod {
+        // kUnset indicates this enum wasn't applicable in the context.
+        kUnset = -1,
+        // kUnknown indicates we were unable to convert the method string to
+        // this enum.
+        kUnknown = 0,
+        kGet = 1,
+        kHead = 2,
+        kPost = 3,
+        KPut = 4,
+        kDelete = 5,
+        kConnect = 6,
+        kOptions = 7,
+        kTrace = 8,
+        kPatch = 9,
+        kMaxValue = kPatch
+      };
+
       // Records the type of any context downgrade due to a cross-site redirect,
       // i.e. whether the spec change in
       // https://github.com/httpwg/http-extensions/pull/1348 changed the result
@@ -102,6 +123,15 @@ class NET_EXPORT CookieOptions {
 
       ContextRedirectTypeBug1221316 redirect_type_bug_1221316 =
           ContextRedirectTypeBug1221316::kUnset;
+
+      // Records the HTTP method of requests that result in a cross-site
+      // redirect downgrade. May be kUnset if there wasn't a downgrade or if the
+      // cookie access wasn't due to a request.
+      //
+      // Note that this field is always set when there was a context
+      // downgrade but the associated histrogram is only recorded when that
+      // context downgrade results in a change in inclusion status.
+      HttpMethod http_method_bug_1221316 = HttpMethod::kUnset;
     };
 
     // The following three constructors apply default values for the metadata
@@ -312,6 +342,8 @@ inline void PrintTo(
       << static_cast<int>(m.cross_site_redirect_downgrade);
   *os << ", redirect_type_bug_1221316: "
       << static_cast<int>(m.redirect_type_bug_1221316);
+  *os << ", http_method_bug_1221316: "
+      << static_cast<int>(m.http_method_bug_1221316);
   *os << " }";
 }
 
