@@ -8,7 +8,7 @@
 #include <string>
 #include <vector>
 
-#include "base/callback_forward.h"
+#include "base/functional/callback_forward.h"
 #include "base/time/time.h"
 #include "net/base/net_export.h"
 #include "net/cookies/canonical_cookie.h"
@@ -44,7 +44,8 @@ enum class StorageAccessResult {
   ACCESS_ALLOWED = 1,
   ACCESS_ALLOWED_STORAGE_ACCESS_GRANT = 2,
   ACCESS_ALLOWED_FORCED = 3,
-  kMaxValue = ACCESS_ALLOWED_FORCED,
+  ACCESS_ALLOWED_TOP_LEVEL_STORAGE_ACCESS_GRANT = 4,
+  kMaxValue = ACCESS_ALLOWED_TOP_LEVEL_STORAGE_ACCESS_GRANT,
 };
 // Helper to fire telemetry indicating if a given request for storage was
 // allowed or not by the provided |result|.
@@ -274,14 +275,14 @@ GetSamePartyStatus(const CanonicalCookie& cookie,
                    const CookieOptions& options,
                    bool same_party_attribute_enabled);
 
-// Takes a callback accepting a CookieAccessResult and returns a callback
-// that accepts a bool, setting the bool to true if the CookieInclusionStatus
-// in CookieAccessResult was set to "include", else sending false.
+// Takes a CookieAccessResult and returns a bool, returning true if the
+// CookieInclusionStatus in CookieAccessResult was set to "include", else
+// returning false.
 //
 // Can be used with SetCanonicalCookie when you don't need to know why a cookie
 // was blocked, only whether it was blocked.
-NET_EXPORT base::OnceCallback<void(CookieAccessResult)>
-AdaptCookieAccessResultToBool(base::OnceCallback<void(bool)> callback);
+NET_EXPORT bool IsCookieAccessResultInclude(
+    CookieAccessResult cookie_access_result);
 
 // Turn a CookieAccessResultList into a CookieList by stripping out access
 // results (for callers who only care about cookies).
