@@ -6,10 +6,10 @@
 
 #include <utility>
 
-#include "base/bind.h"
-#include "base/callback_helpers.h"
 #include "base/check_op.h"
 #include "base/compiler_specific.h"
+#include "base/functional/bind.h"
+#include "base/functional/callback_helpers.h"
 #include "base/location.h"
 #include "base/notreached.h"
 #include "base/task/single_thread_task_runner.h"
@@ -35,29 +35,32 @@ EntryImpl* LeakEntryImpl(scoped_refptr<EntryImpl> entry) {
 
 }  // namespace
 
-BackendIO::BackendIO(InFlightIO* controller,
+BackendIO::BackendIO(InFlightBackendIO* controller,
                      BackendImpl* backend,
                      net::CompletionOnceCallback callback)
     : BackendIO(controller, backend) {
   callback_ = std::move(callback);
 }
 
-BackendIO::BackendIO(InFlightIO* controller,
+BackendIO::BackendIO(InFlightBackendIO* controller,
                      BackendImpl* backend,
                      EntryResultCallback callback)
     : BackendIO(controller, backend) {
   entry_result_callback_ = std::move(callback);
 }
 
-BackendIO::BackendIO(InFlightIO* controller,
+BackendIO::BackendIO(InFlightBackendIO* controller,
                      BackendImpl* backend,
                      RangeResultCallback callback)
     : BackendIO(controller, backend) {
   range_result_callback_ = std::move(callback);
 }
 
-BackendIO::BackendIO(InFlightIO* controller, BackendImpl* backend)
-    : BackgroundIO(controller), backend_(backend) {
+BackendIO::BackendIO(InFlightBackendIO* controller, BackendImpl* backend)
+    : BackgroundIO(controller),
+      backend_(backend),
+      background_task_runner_(controller->background_thread()) {
+  DCHECK(background_task_runner_);
   start_time_ = base::TimeTicks::Now();
 }
 
@@ -74,8 +77,7 @@ void BackendIO::OnIOComplete(int result) {
   DCHECK(IsEntryOperation());
   DCHECK_NE(result, net::ERR_IO_PENDING);
   result_ = result;
-  if (notify_controller_)
-    NotifyController();
+  NotifyController();
 }
 
 // Runs on the primary thread.
@@ -259,7 +261,22 @@ void BackendIO::ReadyForSparseIO(EntryImpl* entry) {
   entry_ = entry;
 }
 
-BackendIO::~BackendIO() = default;
+BackendIO::~BackendIO() {
+  if (!did_notify_controller_io_signalled() && out_entry_) {
+    // At this point it's very likely the Entry does not have a
+    // `background_queue_` so that Close() would do nothing. Post an empty
+    // task to the background task runner, which should effectively destroy
+    // the entry as there are no more references. Destruction has to happen
+    // on the background task runner.
+    scoped_refptr<EntryImpl> entry(out_entry_.ExtractAsDangling());
+    // This balances the ref taken in LeakEntryImpl().
+    entry->Release();
+    // This should be the last ref.
+    DCHECK(entry->HasOneRef());
+    background_task_runner_->PostTask(
+        FROM_HERE, base::DoNothingWithBoundArgs(std::move(entry)));
+  }
+}
 
 bool BackendIO::ReturnsEntry() {
   return operation_ == OP_OPEN || operation_ == OP_CREATE ||
@@ -373,16 +390,11 @@ void BackendIO::ExecuteEntryOperation() {
           entry_->ReadDataImpl(index_, offset_, buf_.get(), buf_len_,
                                base::BindOnce(&BackendIO::OnIOComplete, this));
       break;
-    case OP_WRITE: {
-      bool optimistic = false;
-      result_ =
-          entry_->WriteDataImpl(index_, offset_, buf_.get(), buf_len_,
-                                base::BindOnce(&BackendIO::OnIOComplete, this),
-                                truncate_, &optimistic);
-      if (optimistic)
-        notify_controller_ = false;
+    case OP_WRITE:
+      result_ = entry_->WriteDataImpl(
+          index_, offset_, buf_.get(), buf_len_,
+          base::BindOnce(&BackendIO::OnIOComplete, this), truncate_);
       break;
-    }
     case OP_READ_SPARSE:
       result_ = entry_->ReadSparseDataImpl(
           offset64_, buf_.get(), buf_len_,
