@@ -31,11 +31,12 @@ namespace net {
 
 namespace {
 
-base::Value ControllerParamsToValue(HttpAuth::Target target, const GURL& url) {
+base::Value::Dict ControllerParamsToValue(HttpAuth::Target target,
+                                          const GURL& url) {
   base::Value::Dict params;
   params.Set("target", HttpAuth::GetAuthTargetString(target));
   params.Set("url", url.spec());
-  return base::Value(std::move(params));
+  return params;
 }
 
 }  // namespace
