@@ -316,10 +316,12 @@ class NET_EXPORT HttpCache : public HttpTransactionFactory {
   friend class MockHttpCache;
   friend class HttpCacheIOCallbackTest;
 
-  FRIEND_TEST_ALL_PREFIXES(HttpCacheTest, SplitCacheWithNetworkIsolationKey);
+  FRIEND_TEST_ALL_PREFIXES(HttpCacheTest_SplitCacheFeature,
+                           SplitCacheWithNetworkIsolationKey);
   FRIEND_TEST_ALL_PREFIXES(HttpCacheTest, NonSplitCache);
-  FRIEND_TEST_ALL_PREFIXES(HttpCacheTest, SplitCache);
-  FRIEND_TEST_ALL_PREFIXES(HttpCacheTest, SplitCacheUsesRegistrableDomain);
+  FRIEND_TEST_ALL_PREFIXES(HttpCacheTest_SplitCacheFeature, SplitCache);
+  FRIEND_TEST_ALL_PREFIXES(HttpCacheTest_SplitCacheFeature,
+                           SplitCacheUsesRegistrableDomain);
 
   using TransactionList = std::list<Transaction*>;
   using TransactionSet = std::unordered_set<Transaction*>;
