@@ -1217,7 +1217,7 @@ bool HttpResponseHeaders::GetAgeValue(base::TimeDelta* result) const {
   // Parse the delta-seconds as 1*DIGIT.
   uint32_t seconds;
   ParseIntError error;
-  if (!ParseUint32(value, &seconds, &error)) {
+  if (!ParseUint32(value, ParseIntFormat::NON_NEGATIVE, &seconds, &error)) {
     if (error == ParseIntError::FAILED_OVERFLOW) {
       // If the Age value cannot fit in a uint32_t, saturate it to a maximum
       // value. This is similar to what RFC 2616 says in section 14.6 for how
@@ -1369,7 +1369,7 @@ bool HttpResponseHeaders::GetContentRangeFor206(
       instance_length);
 }
 
-base::Value HttpResponseHeaders::NetLogParams(
+base::Value::Dict HttpResponseHeaders::NetLogParams(
     NetLogCaptureMode capture_mode) const {
   base::Value::Dict dict;
   base::Value::List headers;
@@ -1383,7 +1383,7 @@ base::Value HttpResponseHeaders::NetLogParams(
     headers.Append(NetLogStringValue(base::StrCat({name, ": ", log_value})));
   }
   dict.Set("headers", std::move(headers));
-  return base::Value(std::move(dict));
+  return dict;
 }
 
 bool HttpResponseHeaders::IsChunkEncoded() const {
