@@ -26,12 +26,12 @@ constexpr const char kNetLogTracingCategory[] = "netlog";
 
 class TracedValue : public base::trace_event::ConvertableToTraceFormat {
  public:
-  explicit TracedValue(base::Value value) : value_(std::move(value)) {}
+  explicit TracedValue(base::Value::Dict value) : value_(std::move(value)) {}
   ~TracedValue() override = default;
 
  private:
   void AppendAsTraceFormat(std::string* out) const override {
-    if (!value_.is_none()) {
+    if (!value_.empty()) {
       std::string tmp;
       base::JSONWriter::Write(value_, &tmp);
       *out += tmp;
@@ -41,7 +41,7 @@ class TracedValue : public base::trace_event::ConvertableToTraceFormat {
   }
 
  private:
-  base::Value value_;
+  base::Value::Dict value_;
 };
 
 }  // namespace
@@ -54,7 +54,7 @@ TraceNetLogObserver::~TraceNetLogObserver() {
 }
 
 void TraceNetLogObserver::OnAddEntry(const NetLogEntry& entry) {
-  base::Value params = entry.params.Clone();
+  base::Value::Dict params = entry.params.Clone();
   switch (entry.phase) {
     case NetLogEventPhase::BEGIN:
       TRACE_EVENT_NESTABLE_ASYNC_BEGIN2(
