@@ -7,11 +7,10 @@
 #include <string>
 #include <utility>
 
-#include "base/bind.h"
+#include "base/functional/bind.h"
 #include "base/metrics/histogram_macros_local.h"
 #include "base/rand_util.h"
 #include "base/task/sequenced_task_runner.h"
-#include "base/threading/thread_task_runner_handle.h"
 #include "net/nqe/network_quality_estimator.h"
 #include "third_party/abseil-cpp/absl/types/optional.h"
 
