@@ -1,4 +1,4 @@
-// Copyright 2015 The Chromium Authors. All rights reserved.
+// Copyright 2015 The Chromium Authors
 // Use of this source code is governed by a BSD-style license that can be
 // found in the LICENSE file.
 
@@ -25,10 +25,10 @@ namespace net {
 
 PropertiesBasedQuicServerInfo::PropertiesBasedQuicServerInfo(
     const quic::QuicServerId& server_id,
-    const NetworkIsolationKey& network_isolation_key,
+    const NetworkAnonymizationKey& network_anonymization_key,
     HttpServerProperties* http_server_properties)
     : QuicServerInfo(server_id),
-      network_isolation_key_(network_isolation_key),
+      network_anonymization_key_(network_anonymization_key),
       http_server_properties_(http_server_properties) {
   DCHECK(http_server_properties_);
 }
@@ -37,7 +37,7 @@ PropertiesBasedQuicServerInfo::~PropertiesBasedQuicServerInfo() = default;
 
 bool PropertiesBasedQuicServerInfo::Load() {
   const string* data = http_server_properties_->GetQuicServerInfo(
-      server_id_, network_isolation_key_);
+      server_id_, network_anonymization_key_);
   string decoded;
   if (!data) {
     RecordQuicServerInfoFailure(PARSE_NO_DATA_FAILURE);
@@ -57,8 +57,8 @@ bool PropertiesBasedQuicServerInfo::Load() {
 void PropertiesBasedQuicServerInfo::Persist() {
   string encoded;
   base::Base64Encode(Serialize(), &encoded);
-  http_server_properties_->SetQuicServerInfo(server_id_, network_isolation_key_,
-                                             encoded);
+  http_server_properties_->SetQuicServerInfo(
+      server_id_, network_anonymization_key_, encoded);
 }
 
 }  // namespace net
