@@ -51,8 +51,7 @@ void ReportingCacheImpl::AddReport(
 
   auto report = std::make_unique<ReportingReport>(
       reporting_source, network_anonymization_key, url, user_agent, group_name,
-      type, std::make_unique<base::Value>(std::move(body)), depth, queued,
-      attempts);
+      type, std::move(body), depth, queued, attempts);
 
   auto inserted = reports_.insert(std::move(report));
   DCHECK(inserted.second);
@@ -111,9 +110,7 @@ base::Value ReportingCacheImpl::GetReportsAsValue() const {
     report_dict.Set("depth", report->depth);
     report_dict.Set("queued", NetLog::TickCountToString(report->queued));
     report_dict.Set("attempts", report->attempts);
-    if (report->body) {
-      report_dict.Set("body", report->body->Clone());
-    }
+    report_dict.Set("body", report->body.Clone());
     switch (report->status) {
       case ReportingReport::Status::DOOMED:
         report_dict.Set("status", "doomed");
@@ -249,10 +246,8 @@ ReportingEndpoint::Statistics* ReportingCacheImpl::GetEndpointStats(
     if (document_endpoints_source_it == document_endpoints_.end())
       return nullptr;
     const auto document_endpoint_it =
-        base::ranges::find_if(document_endpoints_source_it->second,
-                              [&group_key](ReportingEndpoint endpoint) {
-                                return endpoint.group_key == group_key;
-                              });
+        base::ranges::find(document_endpoints_source_it->second, group_key,
+                           &ReportingEndpoint::group_key);
     // The endpoint may have been removed while the upload was in progress. In
     // that case, we no longer care about the stats for the removed endpoint.
     if (document_endpoint_it == document_endpoints_source_it->second.end())
