@@ -10,16 +10,13 @@
 
 #include "base/time/time.h"
 #include "base/unguessable_token.h"
+#include "base/values.h"
 #include "net/base/net_export.h"
 #include "net/base/network_anonymization_key.h"
 #include "net/reporting/reporting_endpoint.h"
 #include "third_party/abseil-cpp/absl/types/optional.h"
 #include "url/gurl.h"
 
-namespace base {
-class Value;
-}  // namespace base
-
 namespace net {
 
 // An undelivered report.
@@ -50,7 +47,7 @@ struct NET_EXPORT ReportingReport {
       const std::string& user_agent,
       const std::string& group,
       const std::string& type,
-      std::unique_ptr<const base::Value> body,
+      base::Value::Dict body,
       int depth,
       base::TimeTicks queued,
       int attempts);
@@ -110,7 +107,7 @@ struct NET_EXPORT ReportingReport {
   std::string type;
 
   // The body of the report. (Included in the delivered report.)
-  std::unique_ptr<const base::Value> body;
+  base::Value::Dict body;
 
   // How many uploads deep the related request was: 0 if the related request was
   // not an upload (or there was no related request), or n+1 if it was an upload
