@@ -6,10 +6,8 @@
 
 #include <string>
 
-#include "base/feature_list.h"
 #include "base/logging.h"
 #include "base/observer_list.h"
-#include "net/base/features.h"
 #include "net/socket/ssl_client_socket_impl.h"
 #include "net/socket/stream_socket.h"
 #include "net/ssl/ssl_client_session_cache.h"
@@ -78,11 +76,6 @@ SSLClientContext::~SSLClientContext() {
   CertDatabase::GetInstance()->RemoveObserver(this);
 }
 
-bool SSLClientContext::EncryptedClientHelloEnabled() const {
-  return config_.ech_enabled &&
-         base::FeatureList::IsEnabled(features::kEncryptedClientHello);
-}
-
 std::unique_ptr<SSLClientSocket> SSLClientContext::CreateSSLClientSocket(
     std::unique_ptr<StreamSocket> stream_socket,
     const HostPortPair& host_and_port,
