@@ -243,7 +243,6 @@ void UDPSocketPosix::ReceivedActivityMonitor::OnTimerFired() {
 
 void UDPSocketPosix::Close() {
   DCHECK_CALLED_ON_VALID_THREAD(thread_checker_);
-  CHECK(!dont_close_);
 
   owned_socket_count_.Reset();
 
@@ -1086,8 +1085,4 @@ int UDPSocketPosix::SetIOSNetworkServiceType(int ios_network_service_type) {
   return OK;
 }
 
-void UDPSocketPosix::SetDontClose(bool dont_close) {
-  dont_close_ = dont_close;
-}
-
 }  // namespace net
