@@ -9,7 +9,7 @@
 #include <utility>
 
 #include "base/logging.h"
-#include "base/threading/thread_task_runner_handle.h"
+#include "base/task/single_thread_task_runner.h"
 #include "net/base/io_buffer.h"
 #include "net/base/net_errors.h"
 #include "net/base/url_util.h"
@@ -47,7 +47,7 @@ RedirectResolver::RedirectResolver(std::unique_ptr<DatagramServerSocket> socket,
   DCHECK(socket_);
   // Start accepting connections in next run loop in case when delegate is not
   // ready to get callbacks.
-  base::ThreadTaskRunnerHandle::Get()->PostTask(
+  base::SingleThreadTaskRunner::GetCurrentDefault()->PostTask(
       FROM_HERE, base::BindOnce(&RedirectResolver::DoRead,
                                 weak_ptr_factory_.GetWeakPtr()));
 }
