@@ -31,9 +31,6 @@ struct TransportSecurityStateEntry {
 
   bool hpkp_include_subdomains = false;
   std::string pinset;
-
-  bool expect_ct = false;
-  std::string expect_ct_report_uri;
 };
 
 using TransportSecurityStateEntries =
@@ -41,8 +38,7 @@ using TransportSecurityStateEntries =
 
 class TransportSecurityStateTrieEntry : public huffman_trie::TrieEntry {
  public:
-  TransportSecurityStateTrieEntry(const NameIDMap& expect_ct_report_uri_map,
-                                  const NameIDMap& pinsets_map,
+  TransportSecurityStateTrieEntry(const NameIDMap& pinsets_map,
                                   TransportSecurityStateEntry* entry);
   ~TransportSecurityStateTrieEntry() override;
 
@@ -51,7 +47,6 @@ class TransportSecurityStateTrieEntry : public huffman_trie::TrieEntry {
   bool WriteEntry(huffman_trie::TrieBitBuffer* writer) const override;
 
  private:
-  const NameIDMap& expect_ct_report_uri_map_;
   const NameIDMap& pinsets_map_;
   TransportSecurityStateEntry* entry_;
 };
