@@ -5,17 +5,14 @@
 
 '''Unit tests for node_io.FileNode'''
 
-from __future__ import print_function
-
 import os
 import sys
 import unittest
+import io
 
 if __name__ == '__main__':
   sys.path.append(os.path.join(os.path.dirname(__file__), '../..'))
 
-from six import StringIO
-
 from grit.node import misc
 from grit.node import node_io
 from grit.node import empty
@@ -34,20 +31,20 @@ def _GetAllCliques(root_node):
 class FileNodeUnittest(unittest.TestCase):
   def testGetPath(self):
     root = misc.GritNode()
-    root.StartParsing(u'grit', None)
-    root.HandleAttribute(u'latest_public_release', u'0')
-    root.HandleAttribute(u'current_release', u'1')
-    root.HandleAttribute(u'base_dir', r'..\resource')
+    root.StartParsing('grit', None)
+    root.HandleAttribute('latest_public_release', '0')
+    root.HandleAttribute('current_release', '1')
+    root.HandleAttribute('base_dir', r'..\resource')
     translations = empty.TranslationsNode()
-    translations.StartParsing(u'translations', root)
+    translations.StartParsing('translations', root)
     root.AddChild(translations)
     file_node = node_io.FileNode()
-    file_node.StartParsing(u'file', translations)
-    file_node.HandleAttribute(u'path', r'flugel\kugel.pdf')
+    file_node.StartParsing('file', translations)
+    file_node.HandleAttribute('path', r'flugel\kugel.pdf')
     translations.AddChild(file_node)
     root.EndParsing()
 
-    self.failUnless(root.ToRealPath(file_node.GetInputPath()) ==
+    self.assertTrue(root.ToRealPath(file_node.GetInputPath()) ==
                     util.normpath(
                       os.path.join(r'../resource', r'flugel/kugel.pdf')))
 
@@ -69,14 +66,14 @@ class FileNodeUnittest(unittest.TestCase):
           </messages>
         </release>
       </grit>'''
-    grd = grd_reader.Parse(StringIO(xml),
-                           util.PathFromRoot('grit/testdata'))
+    grd = grd_reader.Parse(io.StringIO(xml), util.PathFromRoot('grit/testdata'))
     grd.SetOutputLanguage('en')
     grd.RunGatherers()
     self.VerifyCliquesContainEnglishAndFrenchAndNothingElse(_GetAllCliques(grd))
 
   def testIffyness(self):
-    grd = grd_reader.Parse(StringIO('''<?xml version="1.0" encoding="UTF-8"?>
+    grd = grd_reader.Parse(
+        io.StringIO('''<?xml version="1.0" encoding="UTF-8"?>
       <grit latest_public_release="2" source_lang_id="en-US" current_release="3" base_dir=".">
         <translations>
           <if expr="lang == 'fr'">
@@ -121,8 +118,7 @@ class FileNodeUnittest(unittest.TestCase):
           </messages>
         </release>
       </grit>'''
-    grd = grd_reader.Parse(StringIO(xml),
-                           util.PathFromRoot('grit/testdata'))
+    grd = grd_reader.Parse(io.StringIO(xml), util.PathFromRoot('grit/testdata'))
     grd.SetOutputLanguage('en')
     grd.RunGatherers()
     self.VerifyCliquesContainEnglishAndFrenchAndNothingElse(_GetAllCliques(grd))
@@ -146,24 +142,25 @@ class FileNodeUnittest(unittest.TestCase):
           </messages>
         </release>
       </grit>'''
-    grd = grd_reader.Parse(StringIO(xml),
+    grd = grd_reader.Parse(io.StringIO(xml),
                            util.PathFromRoot('grit/test/data'),
                            defines={})
     grd.SetOutputLanguage('en')
     grd.RunGatherers()
     outputs = grd.GetChildrenOfType(node_io.OutputNode)
     active = set(grd.ActiveDescendants())
-    self.failUnless(outputs[0] in active)
-    self.failUnless(outputs[0].GetType() == 'rc_header')
-    self.failUnless(outputs[1] in active)
-    self.failUnless(outputs[1].GetType() == 'rc_all')
-    self.failUnless(outputs[2] not in active)
-    self.failUnless(outputs[2].GetType() == 'rc_all')
+    self.assertTrue(outputs[0] in active)
+    self.assertTrue(outputs[0].GetType() == 'rc_header')
+    self.assertTrue(outputs[1] in active)
+    self.assertTrue(outputs[1].GetType() == 'rc_all')
+    self.assertTrue(outputs[2] not in active)
+    self.assertTrue(outputs[2].GetType() == 'rc_all')
 
   # Verify that 'iw' and 'no' language codes in xtb files are mapped to 'he' and
   # 'nb'.
   def testLangCodeMapping(self):
-    grd = grd_reader.Parse(StringIO('''<?xml version="1.0" encoding="UTF-8"?>
+    grd = grd_reader.Parse(
+        io.StringIO('''<?xml version="1.0" encoding="UTF-8"?>
       <grit latest_public_release="2" source_lang_id="en-US" current_release="3" base_dir=".">
         <translations>
           <file path="generated_resources_no.xtb" lang="nb" />
