@@ -5,13 +5,10 @@
 '''Adaptation of the extern.tclib classes for our needs.
 '''
 
-from __future__ import print_function
 
 import functools
 import re
 
-import six
-
 from grit import exception
 from grit import lazy_re
 import grit.extern.tclib
@@ -29,7 +26,7 @@ def Identity(i):
   return i
 
 
-class BaseMessage(object):
+class BaseMessage:
   '''Base class with methods shared by Message and Translation.
   '''
 
@@ -87,7 +84,7 @@ class BaseMessage(object):
     '''
     bits = []
     for item in self.parts:
-      if isinstance(item, six.string_types):
+      if isinstance(item, str):
         bits.append(escaping_function(item))
       else:
         bits.append(item.GetOriginal())
@@ -122,7 +119,7 @@ class BaseMessage(object):
     self.dirty = True
 
   def AppendText(self, text):
-    assert isinstance(text, six.string_types)
+    assert isinstance(text, str)
     assert text != ''
 
     self.parts.append(text)
@@ -180,7 +177,7 @@ class Message(BaseMessage):
 
   def __init__(self, text='', placeholders=[], description='', meaning='',
                assigned_id=None):
-    super(Message, self).__init__(text, placeholders, description, meaning)
+    super().__init__(text, placeholders, description, meaning)
     self.assigned_id = assigned_id
 
   def ToTclibMessage(self):
@@ -193,7 +190,7 @@ class Message(BaseMessage):
     if self.assigned_id:
       return self.assigned_id
 
-    return super(Message, self).GetId()
+    return super().GetId()
 
   def HasAssignedId(self):
     '''Returns True if this message has an assigned id.'''
@@ -204,7 +201,7 @@ class Translation(BaseMessage):
   '''A translation.'''
 
   def __init__(self, text='', id='', placeholders=[], description='', meaning=''):
-    super(Translation, self).__init__(text, placeholders, description, meaning)
+    super().__init__(text, placeholders, description, meaning)
     self.id = id
 
   def GetId(self):
