@@ -361,7 +361,7 @@ bool GURL::SchemeIs(base::StringPiece lower_ascii_scheme) const {
 }
 
 bool GURL::SchemeIsHTTPOrHTTPS() const {
-  return SchemeIs(url::kHttpScheme) || SchemeIs(url::kHttpsScheme);
+  return SchemeIs(url::kHttpsScheme) || SchemeIs(url::kHttpScheme);
 }
 
 bool GURL::SchemeIsWSOrWSS() const {
