@@ -15,6 +15,10 @@ BASE_FEATURE(kRecordIDNA2008Metrics,
              "RecordIDNA2008Metrics",
              base::FEATURE_ENABLED_BY_DEFAULT);
 
+BASE_FEATURE(kStrictIPv4EmbeddedIPv6AddressParsing,
+             "StrictIPv4EmbeddedIPv6AddressParsing",
+             base::FEATURE_DISABLED_BY_DEFAULT);
+
 bool IsUsingIDNA2008NonTransitional() {
   return base::FeatureList::IsEnabled(kUseIDNA2008NonTransitional);
 }
